% Auto-generated chapter 70 for bukhari
% Hadiths in this chapter: 95

\hadithdefcmd{bukhari}{5373}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مُوسَى الأَشْعَرِي ِّ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَطْعِمُوا الْجَائِعَ، وَعُودُوا الْمَرِيضَ، وَفُكُّوا الْعَانِيَ ‏"‏‏.‏ قَالَ سُفْيَانُ وَالْعَانِي الأَسِيرُ‏.‏\hadithno{5373}\hadithtrans{Narrated Abu Musa Al-Ash`ari:The Prophet (ﷺ) said, "Give food to the hungry, pay a visit to the sick and release (set free) the one in captivity (by paying his ransom)}}
\hadithdefcmd{bukhari}{5374}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَا شَبِعَ آلُ مُحَمَّدٍ صلى الله عليه وسلم مِنْ طَعَامٍ ثَلاَثَةَ أَيَّامٍ حَتَّى قُبِضَ‏.‏\hadithno{5374}\hadithtrans{Narrated Abu Huraira: The family of Muhammad did not eat their fill for three successive days till he died}}
\hadithdefcmd{bukhari}{5375}{وَعَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَصَابَنِي جَهْدٌ شَدِيدٌ فَلَقِيتُ عُمَرَ بْنَ الْخَطَّابِ، فَاسْتَقْرَأْتُهُ آيَةً مِنْ كِتَابِ اللَّهِ، فَدَخَلَ دَارَهُ وَفَتَحَهَا عَلَىَّ، فَمَشَيْتُ غَيْرَ بَعِيدٍ، فَخَرَرْتُ لِوَجْهِي مِنَ الْجَهْدِ وَالْجُوعِ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ عَلَى رَأْسِي فَقَالَ ‏"‏ يَا أَبَا هُرَيْرَةَ ‏"‏‏.‏ فَقُلْتُ لَبَّيْكَ رَسُولَ اللَّهِ وَسَعْدَيْكَ‏.‏ فَأَخَذَ بِيَدِي فَأَقَامَنِي، وَعَرَفَ الَّذِي بِي، فَانْطَلَقَ بِي إِلَى رَحْلِهِ، فَأَمَرَ لِي بِعُسٍّ مِنْ لَبَنٍ فَشَرِبْتُ مِنْهُ، ثُمَّ قَالَ ‏"‏ عُدْ يَا أَبَا هِرٍّ ‏"‏‏.‏ فَعُدْتُ فَشَرِبْتُ، ثُمَّ قَالَ ‏"‏ عُدْ ‏"‏‏.‏ فَعُدْتُ فَشَرِبْتُ حَتَّى اسْتَوَى بَطْنِي فَصَارَ كَالْقِدْحِ ـ قَالَ ـ فَلَقِيتُ عُمَرَ وَذَكَرْتُ لَهُ الَّذِي كَانَ مِنْ أَمْرِي وَقُلْتُ لَهُ تَوَلَّى اللَّهُ ذَلِكَ مَنْ كَانَ أَحَقَّ بِهِ مِنْكَ يَا عُمَرُ، وَاللَّهِ لَقَدِ اسْتَقْرَأْتُكَ الآيَةَ وَلأَنَا أَقْرَأُ لَهَا مِنْكَ‏.‏ قَالَ عُمَرُ وَاللَّهِ لأَنْ أَكُونَ أَدْخَلْتُكَ أَحَبُّ إِلَىَّ مِنْ أَنْ يَكُونَ لِي مِثْلُ حُمْرِ النَّعَمِ‏.‏\hadithno{5375}\hadithtrans{Narrated Abu Huraira: Once while I was in a state of fatigue (because of severe hunger), I met 'Umar bin Al-Khattab, so I asked him to recite a verse from Allah's Book to me. He entered his house and interpreted it to me. (Then I went out and) after walking for a short distance, I fell on my face because of fatigue and severe hunger. Suddenly I saw Allah's Apostle standing by my head. He said, "O Abu Huraira!" I replied, "Labbaik, O Allah's Messenger (ﷺ), and Sadaik!" Then he held me by the hand, and made me get up. Then he came to know what I was suffering from. He took me to his house, and ordered a big bowl of milk for me. I drank thereof and he said, "Drink more, O Abu Hirr!" So I drank again, whereupon he again said, "Drink more." So I drank more till my belly became full and looked like a bowl. Afterwards I met 'Umar and mentioned to him what had happened to me, and said to him, "Somebody, who had more right than you, O 'Umar, took over the case. By Allah, I asked you to recite a Verse to me while I knew it better than you." On that Umar said to me, "By Allah, if I admitted and entertained you, it would have been dearer to me than having nice red camels}}
\hadithdefcmd{bukhari}{5376}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، أَخْبَرَنَا سُفْيَانُ، قَالَ الْوَلِيدُ بْنُ كَثِيرٍ أَخْبَرَنِي أَنَّهُ، سَمِعَ وَهْبَ بْنَ كَيْسَانَ، أَنَّهُ سَمِعَ عُمَرَ بْنَ أَبِي سَلَمَةَ، يَقُولُ كُنْتُ غُلاَمًا فِي حَجْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَتْ يَدِي تَطِيشُ فِي الصَّحْفَةِ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا غُلاَمُ سَمِّ اللَّهَ، وَكُلْ بِيَمِينِكَ وَكُلْ مِمَّا يَلِيكَ ‏"‏‏.‏ فَمَا زَالَتْ تِلْكَ طِعْمَتِي بَعْدُ‏.‏\hadithno{5376}\hadithtrans{Narrated `Umar bin Abi Salama:I was a boy under the care of Allah's Messenger (ﷺ) and my hand used to go around the dish while I was eating. So Allah's Messenger (ﷺ) said to me, 'O boy! Mention the Name of Allah and eat with your right hand, and eat of the dish what is nearer to you." Since then I have applied those instructions when eating}}
\hadithdefcmd{bukhari}{5377}{حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ الدِّيلِيِّ، عَنْ وَهْبِ بْنِ كَيْسَانَ أَبِي نُعَيْمٍ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ ـ وَهْوَ ابْنُ أُمِّ سَلَمَةَ ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَ أَكَلْتُ يَوْمًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم طَعَامًا فَجَعَلْتُ آكُلُ مِنْ نَوَاحِي الصَّحْفَةِ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلْ مِمَّا يَلِيكَ ‏"‏‏.‏\hadithno{5377}\hadithtrans{Narrated `Umar bin Al Salama:Who was the son of Um Salama, the wife of the Prophet: Once I ate a meal with Allah's Messenger (ﷺ) and I was eating from all sides of the dish. So Allah's Messenger (ﷺ) said to me, "Eat of the dish what is nearer to you}}
\hadithdefcmd{bukhari}{5378}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ وَهْبِ بْنِ كَيْسَانَ أَبِي نُعَيْمٍ، قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِطَعَامٍ وَمَعَهُ رَبِيبُهُ عُمَرُ بْنُ أَبِي سَلَمَةَ فَقَالَ ‏ "‏ سَمِّ اللَّهَ، وَكُلْ مِمَّا يَلِيكَ ‏"‏‏.‏\hadithno{5378}\hadithtrans{Narrated Wahb bin Kaisan Abi Nu'aim:A meal was brought to Allah's Messenger (ﷺ) while his step-son, `Umar bin Abi Salama was with him. Allah's Messenger (ﷺ) said to him, "Mention the Name of Allah and eat of the dish what is nearer to you}}
\hadithdefcmd{bukhari}{5379}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ إِنَّ خَيَّاطًا دَعَا رَسُولَ اللَّهِ صلى الله عليه وسلم لِطَعَامٍ صَنَعَهُ ـ قَالَ أَنَسٌ ـ فَذَهَبْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَأَيْتُهُ يَتَتَبَّعُ الدُّبَّاءَ مِنْ حَوَالَىِ الْقَصْعَةِ ـ قَالَ ـ فَلَمْ أَزَلْ أُحِبُّ الدُّبَّاءَ مِنْ يَوْمِئِذٍ‏.‏\hadithno{5379}\hadithtrans{Narrated Anas bin Malik:A tailor invited Allah's Messenger (ﷺ) to a meal which he had prepared. I went along with Allah's Messenger (ﷺ) and saw him seeking to eat the pieces of gourd from the various sides of the dish. Since that day I have liked to eat gourd. `Umar bin Abi Salama said: The Prophet, said to me, "Eat with your right hand}}
\hadithdefcmd{bukhari}{5380}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا شُعْبَةُ، عَنْ أَشْعَثَ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُحِبُّ التَّيَمُّنَ مَا اسْتَطَاعَ فِي طُهُورِهِ وَتَنَعُّلِهِ وَتَرَجُّلِهِ‏.‏ وَكَانَ قَالَ بِوَاسِطٍ قَبْلَ هَذَا فِي شَأْنِهِ كُلِّهِ‏.‏\hadithno{5380}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to love to start doing things from the right side whenever possible, in performing ablution, putting on his shoes, and combing his hair. (Al-Ash'ath said: The Prophet (ﷺ) used to do so in all his affairs}}
\hadithdefcmd{bukhari}{5381}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ أَبُو طَلْحَةَ لأُمِّ سُلَيْمٍ لَقَدْ سَمِعْتُ صَوْتَ، رَسُولِ اللَّهِ صلى الله عليه وسلم ضَعِيفًا أَعْرِفُ فِيهِ الْجُوعَ، فَهَلْ عِنْدَكِ مِنْ شَىْءٍ فَأَخْرَجَتْ أَقْرَاصًا مِنْ شَعِيرٍ، ثُمَّ أَخْرَجَتْ خِمَارًا لَهَا فَلَفَّتِ الْخُبْزَ بِبَعْضِهِ، ثُمَّ دَسَّتْهُ تَحْتَ ثَوْبِي وَرَدَّتْنِي بِبَعْضِهِ، ثُمَّ أَرْسَلَتْنِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَذَهَبْتُ بِهِ فَوَجَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ وَمَعَهُ النَّاسُ، فَقُمْتُ عَلَيْهِمْ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْسَلَكَ أَبُو طَلْحَةَ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ بِطَعَامٍ ‏"‏‏.‏ قَالَ فَقُلْتُ نَعَمْ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمَنْ مَعَهُ ‏"‏ قُومُوا ‏"‏‏.‏ فَانْطَلَقَ وَانْطَلَقْتُ بَيْنَ أَيْدِيهِمْ حَتَّى جِئْتُ أَبَا طَلْحَةَ، فَقَالَ أَبُو طَلْحَةَ يَا أُمَّ سُلَيْمٍ قَدْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالنَّاسِ، وَلَيْسَ عِنْدَنَا مِنَ الطَّعَامِ مَا نُطْعِمُهُمْ‏.‏ فَقَالَتِ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ فَانْطَلَقَ أَبُو طَلْحَةَ حَتَّى لَقِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَقْبَلَ أَبُو طَلْحَةَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى دَخَلاَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلُمِّي يَا أُمَّ سُلَيْمٍ مَا عِنْدَكِ ‏"‏‏.‏ فَأَتَتْ بِذَلِكَ الْخُبْزِ فَأَمَرَ بِهِ فَفُتَّ وَعَصَرَتْ أُمُّ سُلَيْمٍ عُكَّةً لَهَا فَأَدَمَتْهُ، ثُمَّ قَالَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا شَاءَ اللَّهُ أَنْ يَقُولَ ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏‏.‏ فَأَذِنَ لَهُمْ، فَأَكَلُوا حَتَّى شَبِعُوا، ثُمَّ خَرَجُوا، ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏‏.‏ فَأَذِنَ لَهُمْ فَأَكَلُوا حَتَّى شَبِعُوا، ثُمَّ خَرَجُوا، ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏‏.‏ فَأَذِنَ لَهُمْ فَأَكَلُوا حَتَّى شَبِعُوا ثُمَّ خَرَجُوا، ثُمَّ أَذِنَ لِعَشَرَةٍ، فَأَكَلَ الْقَوْمُ كُلُّهُمْ وَشَبِعُوا، وَالْقَوْمُ ثَمَانُونَ رَجُلاً‏.‏\hadithno{5381}\hadithtrans{Narrated Anas bin Malik:Abu Talha said to Um Sulaim, "I have heard the voice of Allah's Messenger (ﷺ) which was feeble, and I think that he is hungry. Have you got something (to eat)?" She took out some loaves of barley bread, then took her face-covering sheet and wrapped the bread in part of it, and pushed it under my garment and turned the rest of it around my body and sent me to Allah's Messenger (ﷺ) . I went with that, and found Allah's Messenger (ﷺ) in the mosque with some people. I stood up near them, and Allah's Messenger (ﷺ) asked me, "Have you been sent by Abu Talha?" I said, "Yes." He asked, "With some food (for us)?" I said, "Yes." Then Allah's Messenger (ﷺ) said to all those who were with him, "Get up!" He set out (and all the people accompanied him) and I proceeded ahead of them till I came to Abu Talha. Abu Talha then said, "O Um Sulaim! Allah's Messenger (ﷺ) has arrived along with the people, and we do not have food enough to feed them all." She said, "Allah and His Apostle know better." So Abu Talha went out till he met Allah's Messenger (ﷺ). Then Abu Talha and Allah's Messenger (ﷺ) came and entered the house. Allah's Apostle said, "Um Sulaim ! Bring whatever you have." She brought that very bread. The Prophet (ﷺ) ordered that it be crushed into small pieces, and Um Sulaim pressed a skin of butter on it. Then Allah's Apostle said whatever Allah wished him to say (to bless the food) and then added, "Admit ten (men)." So they were admitted, ate their fill and went out. The Prophet (ﷺ) then said, "Admit ten (more)." They were admitted, ate their full, and went out. He then again said, "Admit ten more!" They were admitted, ate their fill, and went out. He admitted ten more, and so all those people ate their fill, and they were eighty men}}
\hadithdefcmd{bukhari}{5382}{حَدَّثَنَا مُوسَى، حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، قَالَ وَحَدَّثَ أَبُو عُثْمَانَ، أَيْضًا عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم ثَلاَثِينَ وَمِائَةً، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ مَعَ أَحَدٍ مِنْكُمْ طَعَامٌ ‏"‏‏.‏ فَإِذَا مَعَ رَجُلٍ صَاعٌ مِنْ طَعَامٍ أَوْ نَحْوُهُ، فَعُجِنَ، ثُمَّ جَاءَ رَجُلٌ مُشْرِكٌ مُشْعَانٌّ طَوِيلٌ بِغَنَمٍ يَسُوقُهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَبَيْعٌ أَمْ عَطِيَّةٌ أَوْ ـ قَالَ ـ هِبَةٌ ‏"‏‏.‏ قَالَ لاَ بَلْ بَيْعٌ‏.‏ قَالَ فَاشْتَرَى مِنْهُ شَاةً فَصُنِعَتْ، فَأَمَرَ نَبِيُّ اللَّهِ صلى الله عليه وسلم بِسَوَادِ الْبَطْنِ يُشْوَى، وَايْمُ اللَّهِ مَا مِنَ الثَّلاَثِينَ وَمِائَةٍ إِلاَّ قَدْ حَزَّ لَهُ حُزَّةً مِنْ سَوَادِ بَطْنِهَا، إِنْ كَانَ شَاهِدًا أَعْطَاهَا إِيَّاهُ، وَإِنْ كَانَ غَائِبًا خَبَأَهَا لَهُ، ثُمَّ جَعَلَ فِيهَا قَصْعَتَيْنِ فَأَكَلْنَا أَجْمَعُونَ وَشَبِعْنَا، وَفَضَلَ فِي الْقَصْعَتَيْنِ، فَحَمَلْتُهُ عَلَى الْبَعِيرِ‏.‏ أَوْ كَمَا قَالَ‏.‏\hadithno{5382}\hadithtrans{Narrated `Abdur-Rahman bin Abu Bakr:We were one hundred and thirty men sitting with the Prophet. The Prophet (ﷺ) said, "Have anyone of you any food with him?" It happened that one man had one Sa of wheat flour (or so) which was turned into dough then. After a while a tall lanky pagan came, driving some sheep. The Prophet (ﷺ) asked, 'Will you sell us (a sheep), or give (it to) us as a gift?" The pagan said, "No, but I will sell it " So the Prophet bought from him a sheep which was slaughtered, and then the Prophet (ﷺ) ordered that the liver, the kidneys, lungs and heart, etc., of that sheep be roasted. By Allah, none of those one hundred and thirty men but had his share of those things. The Prophet (ﷺ) gave to those who were present, and also kept a share for those who were absent He then served that cooked sheep in two big trays and we all ate together our fill; yet there remained a part of it in those two trays which I carried on the camel}}
\hadithdefcmd{bukhari}{5383}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مَنْصُورٌ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ تُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم حِينَ شَبِعْنَا مِنَ الأَسْوَدَيْنِ التَّمْرِ وَالْمَاءِ‏.‏\hadithno{5383}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) died when we had satisfied our hunger with the two black things, i.e. dates and water}}
\hadithdefcmd{bukhari}{5384}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ يَحْيَى بْنُ سَعِيدٍ سَمِعْتُ بُشَيْرَ بْنَ يَسَارٍ، يَقُولُ حَدَّثَنَا سُوَيْدُ بْنُ النُّعْمَانِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى خَيْبَرَ، فَلَمَّا كُنَّا بِالصَّهْبَاءِ ـ قَالَ يَحْيَى وَهْىَ مِنْ خَيْبَرَ عَلَى رَوْحَةٍ ـ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِطَعَامٍ، فَمَا أُتِيَ إِلاَّ بِسَوِيقٍ، فَلُكْنَاهُ فَأَكَلْنَا مِنْهُ، ثُمَّ دَعَا بِمَاءٍ فَمَضْمَضَ وَمَضْمَضْنَا، فَصَلَّى بِنَا الْمَغْرِبَ وَلَمْ يَتَوَضَّأْ‏.‏ قَالَ سُفْيَانُ سَمِعْتُهُ مِنْهُ عَوْدًا وَبَدْءًا‏.‏\hadithno{5384}\hadithtrans{Narrated Suwaid bin An-Nu`man:We went out with Allah's Messenger (ﷺ) to Khaibar, and when we were at As-Sahba', (Yahya, a sub-narrator said, "As-Sahba' is a place at a distance of one day's journey to Khaibar)." Allah's Messenger (ﷺ) asked the people to bring their food, but there was nothing with the people except Sawiq. So we all chewed and ate of it. Then the Prophet (ﷺ) asked for some water and he rinsed his mouth, and we too, rinsed our mouths. Then he led us in the Maghrib prayer without performing ablution (again)}}
\hadithdefcmd{bukhari}{5385}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، قَالَ كُنَّا عِنْدَ أَنَسٍ وَعِنْدَهُ خَبَّازٌ لَهُ فَقَالَ مَا أَكَلَ النَّبِيُّ صلى الله عليه وسلم خُبْزًا مُرَقَّقًا وَلاَ شَاةً مَسْمُوطَةً حَتَّى لَقِيَ اللَّهَ‏.‏\hadithno{5385}\hadithtrans{Narrated Qatada:We were in the company of Anas whose baker was with him. Anas said, The Prophet (ﷺ) did not eat thin bread, or a roasted sheep till he met Allah (died)}}
\hadithdefcmd{bukhari}{5386}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ يُونُسَ ـ قَالَ عَلِيٌّ هُوَ الإِسْكَافُ ـ عَنْ قَتَادَةَ، عَنْ أَنَسٍ، رضى الله عنه قَالَ مَا عَلِمْتُ النَّبِيَّ صلى الله عليه وسلم أَكَلَ عَلَى سُكُرُّجَةٍ قَطُّ، وَلاَ خُبِزَ لَهُ مُرَقَّقٌ قَطُّ، وَلاَ أَكَلَ عَلَى خِوَانٍ‏.‏ قِيلَ لِقَتَادَةَ فَعَلَى مَا كَانُوا يَأْكُلُونَ قَالَ عَلَى السُّفَرِ‏.‏\hadithno{5386}\hadithtrans{Narrated Anas:To the best of my knowledge, the Prophet (ﷺ) did not take his meals in a big tray at all, nor did he ever eat well-baked thin bread, nor did he ever eat at a dining table}}
\hadithdefcmd{bukhari}{5387}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنِي حُمَيْدٌ، أَنَّهُ سَمِعَ أَنَسًا، يَقُولُ قَامَ النَّبِيُّ صلى الله عليه وسلم يَبْنِي بِصَفِيَّةَ فَدَعَوْتُ الْمُسْلِمِينَ إِلَى وَلِيمَتِهِ أَمَرَ بِالأَنْطَاعِ فَبُسِطَتْ فَأُلْقِيَ عَلَيْهَا التَّمْرُ وَالأَقِطُ وَالسَّمْنُ‏.‏ وَقَالَ عَمْرٌو عَنْ أَنَسٍ بَنَى بِهَا النَّبِيُّ صلى الله عليه وسلم ثُمَّ صَنَعَ حَيْسًا فِي نِطَعٍ‏.‏\hadithno{5387}\hadithtrans{Narrated Anas:The Prophet (ﷺ) halted to consummate his marriage with Safiyya. I invited the Muslims to his wedding banquet. He ordered that leather dining sheets be spread. Then dates, dried yoghurt and butter were put on those sheets. Anas added: The Prophet (ﷺ) consummated his marriage with Safiyya (during a journey) whereupon Hais (sweet dish) was served on a leather dining sheet}}
\hadithdefcmd{bukhari}{5388}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، وَعَنْ وَهْبِ بْنِ كَيْسَانَ، قَالَ كَانَ أَهْلُ الشَّأْمِ يُعَيِّرُونَ ابْنَ الزُّبَيْرِ يَقُولُونَ يَا ابْنَ ذَاتِ النِّطَاقَيْنِ‏.‏ فَقَالَتْ لَهُ أَسْمَاءُ يَا بُنَىَّ إِنَّهُمْ يُعَيِّرُونَكَ بِالنِّطَاقَيْنِ، هَلْ تَدْرِي مَا كَانَ النِّطَاقَانِ إِنَّمَا كَانَ نِطَاقِي شَقَقْتُهُ نِصْفَيْنِ، فَأَوْكَيْتُ قِرْبَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِأَحَدِهِمَا، وَجَعَلْتُ فِي سُفْرَتِهِ آخَرَ، قَالَ فَكَانَ أَهْلُ الشَّأْمِ إِذَا عَيَّرُوهُ بِالنِّطَاقَيْنِ يَقُولُ إِيهًا وَالإِلَهْ‏.‏ تِلْكَ شَكَاةٌ ظَاهِرٌ عَنْكَ عَارُهَا‏.‏\hadithno{5388}\hadithtrans{Narrated Wahb bin Kaisan:The People of Sham taunted `Abdullah bin Az-Zubair by calling him "The son of Dhatin-Nataqain" (the woman who has two waist-belts). (His mother) (Asma, said to him, "O my son! They taunt you with "Nataqain". Do you know what the Nataqain were? That was my waist-belt which I divided in two parts. I tied the water skin of Allah's Messenger (ﷺ) with one part, and with the other part I tied his food container}}
\hadithdefcmd{bukhari}{5389}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ أُمَّ حُفَيْدٍ بِنْتَ الْحَارِثِ بْنِ حَزْن ٍ ـ خَالَةَ ابْنِ عَبَّاسٍ ـ أَهْدَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم سَمْنًا وَأَقِطًا وَأَضُبًّا، فَدَعَا بِهِنَّ فَأُكِلْنَ عَلَى مَائِدَتِهِ، وَتَرَكَهُنَّ النَّبِيُّ صلى الله عليه وسلم كَالْمُسْتَقْذِرِ لَهُنَّ، وَلَوْ كُنَّ حَرَامًا مَا أُكِلْنَ عَلَى مَائِدَةِ النَّبِيِّ صلى الله عليه وسلم وَلاَ أَمَرَ بِأَكْلِهِنَّ‏.‏\hadithno{5389}\hadithtrans{Narrated Ibn `Abbas:that his aunt, Um Hufaid bint Al-Harith bin Hazn, presented to the Prophet (ﷺ) butter, dried yoghurt and mastigures. The Prophet (ﷺ) invited the people to those mastigures and they were eaten on his dining sheet, but the Prophet (ﷺ) did not eat of it, as if he disliked it. Nevertheless. if it was unlawful to eat that, the people would not have eaten it on the dining sheet of the Prophet (ﷺ) nor would he have ordered that they be eaten}}
\hadithdefcmd{bukhari}{5390}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ يَحْيَى، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ سُوَيْدِ بْنِ النُّعْمَانِ، أَنَّهُ أَخْبَرَهُ أَنَّهُمْ، كَانُوا مَعَ النَّبِيِّ صلى الله عليه وسلم بِالصَّهْبَاءِ ـ وَهْىَ عَلَى رَوْحَةٍ مِنْ خَيْبَرَ ـ فَحَضَرَتِ الصَّلاَةُ، فَدَعَا بِطَعَامٍ فَلَمْ يَجِدْهُ إِلاَّ سَوِيقًا، فَلاَكَ مِنْهُ فَلُكْنَا مَعَهُ، ثُمَّ دَعَا بِمَاءٍ فَمَضْمَضَ، ثُمَّ صَلَّى وَصَلَّيْنَا، وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{5390}\hadithtrans{Narrated Suwaid bin An-Nu`man:that while they were with the Prophet (ﷺ) at As-Sahba' which was at a distance of one day's journey from Khaibar the prayer became due, and the Prophet (ﷺ) asked the people for food but there was nothing with the people except Sawiq. He ate of it and we ate along with him, and then he asked for water and rinsed his mouth (with it), and then offered the (Maghrib) prayer and we too offered the prayer but the Prophet did not perform ablution (again after eating the Sawiq)}}
\hadithdefcmd{bukhari}{5391}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو أُمَامَةَ بْنُ سَهْلِ بْنِ حُنَيْفٍ الأَنْصَارِيُّ، أَنَّ ابْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ خَالِدَ بْنَ الْوَلِيدِ الَّذِي يُقَالُ لَهُ سَيْفُ اللَّهِ أَخْبَرَهُ أَنَّهُ، دَخَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى مَيْمُونَةَ ـ وَهْىَ خَالَتُهُ وَخَالَةُ ابْنِ عَبَّاسٍ ـ فَوَجَدَ عِنْدَهَا ضَبًّا مَحْنُوذًا، قَدِمَتْ بِهِ أُخْتُهَا حُفَيْدَةُ بِنْتُ الْحَارِثِ مِنْ نَجْدٍ، فَقَدَّمَتِ الضَّبَّ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ قَلَّمَا يُقَدِّمُ يَدَهُ لِطَعَامٍ حَتَّى يُحَدَّثَ بِهِ وَيُسَمَّى لَهُ، فَأَهْوَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ إِلَى الضَّبِّ، فَقَالَتِ امْرَأَةٌ مِنَ النِّسْوَةِ الْحُضُورِ أَخْبِرْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا قَدَّمْتُنَّ لَهُ، هُوَ الضَّبُّ يَا رَسُولَ اللَّهِ‏.‏ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ عَنِ الضَّبِّ، فَقَالَ خَالِدُ بْنُ الْوَلِيدِ أَحَرَامٌ الضَّبُّ يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ لاَ وَلَكِنْ لَمْ يَكُنْ بِأَرْضِ قَوْمِي فَأَجِدُنِي أَعَافُهُ ‏"‏‏.‏ قَالَ خَالِدٌ فَاجْتَرَرْتُهُ فَأَكَلْتُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَنْظُرُ إِلَىَّ‏.‏\hadithno{5391}\hadithtrans{Narrated Khalid bin Al-Walid:That he went with Allah's Messenger (ﷺ) to the house of Maimuna, who was his and Ibn `Abbas' aunt. He found with her a roasted mastigure which her sister Hufaida bint Al-Harith had brought from Najd. Maimuna presented the mastigure before Allah's Messenger (ﷺ) who rarely started eating any (unfamiliar) food before it was described and named for him. (But that time) Allah's Messenger (ﷺ) stretched his hand towards the (meat of the) mastigure whereupon a lady from among those who were present, said, "You should inform Allah's Messenger (ﷺ) of what you have presented to him. O Allah's Messenger (ﷺ)! It is the meat of a mastigure." (On learning that) Allah's Messenger (ﷺ) withdrew his hand from the meat of the mastigure. Khalid bin Al-Walid said, "O Allah's Messenger (ﷺ)! Is this unlawful to eat?" Allah's Messenger (ﷺ) replied, "No, but it is not found in the land of my people, so I do not like it." Khalid said, "Then I pulled the mastigure (meat) towards me and ate it while Allah's Messenger (ﷺ) was looking at me}}
\hadithdefcmd{bukhari}{5392}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، وَحَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ طَعَامُ الاِثْنَيْنِ كَافِي الثَّلاَثَةِ، وَطَعَامُ الثَّلاَثَةِ كَافِي الأَرْبَعَةِ ‏"‏‏.‏\hadithno{5392}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The food for two persons is sufficient for three, and the food of three persons is sufficient for four persons}}
\hadithdefcmd{bukhari}{5393}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، عَنْ وَاقِدِ بْنِ مُحَمَّدٍ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ لاَ يَأْكُلُ حَتَّى يُؤْتَى بِمِسْكِينٍ يَأْكُلُ مَعَهُ، فَأَدْخَلْتُ رَجُلاً يَأْكُلُ مَعَهُ فَأَكَلَ كَثِيرًا فَقَالَ يَا نَافِعُ لاَ تُدْخِلْ هَذَا عَلَىَّ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْمُؤْمِنُ يَأْكُلُ فِي مِعًى وَاحِدٍ وَالْكَافِرُ يَأْكُلُ فِي سَبْعَةِ أَمْعَاءٍ ‏"‏‏.‏\hadithno{5393}\hadithtrans{Narrated Nafi`:Ibn `Umar never used to take his meal unless a poor man was called to eat with him. One day I brought a poor man to eat with him, the man ate too much, whereupon Ibn `Umar said, "O Nafi`! Don't let this man enter my house, for I heard the Prophet (ﷺ) saying, "A believer eats in one intestine (is satisfied with a little food), and a kafir (unbeliever) eats in seven intestines (eats much food)}}
\hadithdefcmd{bukhari}{5394}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمُؤْمِنَ يَأْكُلُ فِي مِعًى وَاحِدٍ، وَإِنَّ الْكَافِرَ ـ أَوِ الْمُنَافِقَ فَلاَ أَدْرِي أَيَّهُمَا قَالَ عُبَيْدُ اللَّهِ ـ يَأْكُلُ فِي سَبْعَةِ أَمْعَاءٍ ‏"‏‏.‏ وَقَالَ ابْنُ بُكَيْرٍ حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ‏.‏\hadithno{5394}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "A believer eats in one intestine (is satisfied with a little food), and a kafir (unbeliever) or a hypocrite eats in seven intestines (eats too much)}}
\hadithdefcmd{bukhari}{5395}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ كَانَ أَبُو نَهِيكٍ رَجُلاً أَكُولاً فَقَالَ لَهُ ابْنُ عُمَرَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْكَافِرَ يَأْكُلُ فِي سَبْعَةِ أَمْعَاءٍ ‏"‏‏.‏ فَقَالَ فَأَنَا أُومِنُ بِاللَّهِ وَرَسُولِهِ‏.‏\hadithno{5395}\hadithtrans{Narrated `Amr:Abu Nahik was avaricious eater. Ibn `Umar said to him, "Allah's Messenger (ﷺ) said, "A Kafir (unbeliever) eats in seven intestines (eats much)." On that Abu Nahik said, "But I believe in Allah and His Apostle}}
\hadithdefcmd{bukhari}{5396}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَأْكُلُ الْمُسْلِمُ فِي مِعًى وَاحِدٍ، وَالْكَافِرُ يَأْكُلُ فِي سَبْعَةِ أَمْعَاءٍ ‏"‏‏.‏\hadithno{5396}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "A Muslim eats in one intestine (i.e. he is satisfied with a little food) while a Kafir (unbeliever) eats in seven intestines (eats much)}}
\hadithdefcmd{bukhari}{5397}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، كَانَ يَأْكُلُ أَكْلاً كَثِيرًا، فَأَسْلَمَ فَكَانَ يَأْكُلُ أَكْلاً قَلِيلاً، فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّ الْمُؤْمِنَ يَأْكُلُ فِي مِعًى وَاحِدٍ، وَالْكَافِرَ يَأْكُلُ فِي سَبْعَةِ أَمْعَاءٍ ‏"‏‏.‏\hadithno{5397}\hadithtrans{Narrated Abu Huraira:A man used to eat much, but when he embraced Islam, he started eating less. That was mentioned to the Prophet (ﷺ) who then said, "A believer eats in one intestine (is satisfied with a little food) and a Kafir eats in seven intestines (eats much)}}
\hadithdefcmd{bukhari}{5398}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا مِسْعَرٌ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، سَمِعْتُ أَبَا جُحَيْفَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ آكُلُ مُتَّكِئًا ‏"‏‏.‏\hadithno{5398}\hadithtrans{Narrated Abu Juhaifa:Allah's Messenger (ﷺ) said, "I do not take my meals while leaning (against something)}}
\hadithdefcmd{bukhari}{5399}{حَدَّثَنِي عُثْمَانُ بْنُ أَبِي شَيْبَةَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، عَنْ أَبِي جُحَيْفَةَ، قَالَ كُنْتُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ لِرَجُلٍ عِنْدَهُ ‏ "‏ لاَ آكُلُ وَأَنَا مُتَّكِئٌ ‏"‏‏.‏\hadithno{5399}\hadithtrans{Narrated Abu Juhaifa:While I was with the Prophet (ﷺ) he said to a man who was with him, "I do not take my meals while leaning}}
\hadithdefcmd{bukhari}{5400}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ خَالِدِ بْنِ الْوَلِيدِ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِضَبٍّ مَشْوِيٍّ، فَأَهْوَى إِلَيْهِ لِيَأْكُلَ فَقِيلَ لَهُ إِنَّهُ ضَبٌّ، فَأَمْسَكَ يَدَهُ، فَقَالَ خَالِدٌ أَحَرَامٌ هُوَ قَالَ ‏ "‏ لاَ، وَلَكِنَّهُ لاَ يَكُونُ بِأَرْضِ قَوْمِي، فَأَجِدُنِي أَعَافُهُ ‏"‏‏.‏ فَأَكَلَ خَالِدٌ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَنْظُرُ‏.‏ قَالَ مَالِكٌ عَنِ ابْنِ شِهَابٍ بِضَبٍّ مَحْنُوذٍ‏.‏\hadithno{5400}\hadithtrans{Narrated Khalid bin Al-Walid:"A roasted mastigure was brought to the Prophet (ﷺ) who stretched his hand towards it to eat it. But it was said to him, "It is a mastigure." So he withdrew his hand. Khalid asked, "Is it unlawful to eat?" the Prophet said, "No, but it is not found in the land of my people and that is why I do not like eating it." So Khalid started eating (it) while Allah's Messenger (ﷺ) was looking at him. An-Nadr said: 'Al-Khazira' (is prepared) from bran while 'Al-Harira' is prepared from milk}}
\hadithdefcmd{bukhari}{5401}{حَدَّثَنِي يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ الأَنْصَارِيُّ، أَنَّ عِتْبَانَ بْنَ مَالِكٍ ـ وَكَانَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِمَّنْ شَهِدَ بَدْرًا مِنَ الأَنْصَارِ ـ أَنَّهُ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَنْكَرْتُ بَصَرِي وَأَنَا أُصَلِّي لِقَوْمِي، فَإِذَا كَانَتِ الأَمْطَارُ سَالَ الْوَادِي الَّذِي بَيْنِي وَبَيْنَهُمْ، لَمْ أَسْتَطِعْ أَنْ آتِيَ مَسْجِدَهُمْ فَأُصَلِّيَ لَهُمْ، فَوَدِدْتُ يَا رَسُولَ اللَّهِ أَنَّكَ تَأْتِي فَتُصَلِّي فِي بَيْتِي، فَأَتَّخِذُهُ مُصَلًّى‏.‏ فَقَالَ ‏"‏ سَأَفْعَلُ إِنْ شَاءَ اللَّهُ ‏"‏‏.‏ قَالَ عِتْبَانُ فَغَدَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ حِينَ ارْتَفَعَ النَّهَارُ، فَاسْتَأْذَنَ النَّبِيُّ صلى الله عليه وسلم فَأَذِنْتُ لَهُ فَلَمْ يَجْلِسْ حَتَّى دَخَلَ الْبَيْتَ، ثُمَّ قَالَ لِي ‏"‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ مِنْ بَيْتِكَ ‏"‏‏.‏ فَأَشَرْتُ إِلَى نَاحِيَةٍ مِنَ الْبَيْتِ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَكَبَّرَ، فَصَفَفْنَا، فَصَلَّى رَكْعَتَيْنِ، ثُمَّ سَلَّمَ وَحَبَسْنَاهُ عَلَى خَزِيرٍ صَنَعْنَاهُ، فَثَابَ فِي الْبَيْتِ رِجَالٌ مِنْ أَهْلِ الدَّارِ ذَوُو عَدَدٍ فَاجْتَمَعُوا، فَقَالَ قَائِلٌ مِنْهُمْ أَيْنَ مَالِكُ بْنُ الدُّخْشُنِ فَقَالَ بَعْضُهُمْ ذَلِكَ مُنَافِقٌ لاَ يُحِبُّ اللَّهَ وَرَسُولَهُ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تَقُلْ، أَلاَ تَرَاهُ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ يُرِيدُ بِذَلِكَ وَجْهَ اللَّهِ ‏"‏‏.‏ قَالَ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ قُلْنَا فَإِنَّا نَرَى وَجْهَهُ وَنَصِيحَتَهُ إِلَى الْمُنَافِقِينَ‏.‏ فَقَالَ ‏"‏ فَإِنَّ اللَّهَ حَرَّمَ عَلَى النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ يَبْتَغِي بِذَلِكَ وَجْهَ اللَّهِ ‏"‏‏.‏ قَالَ ابْنُ شِهَابٍ ثُمَّ سَأَلْتُ الْحُصَيْنَ بْنَ مُحَمَّدٍ الأَنْصَارِيَّ أَحَدَ بَنِي سَالِمٍ وَكَانَ مِنْ سَرَاتِهِمْ عَنْ حَدِيثِ مَحْمُودٍ فَصَدَّقَهُ‏.‏\hadithno{5401}\hadithtrans{Narrated 'Urban bin Malik:who attended the Badr battle and was from the Ansar, that he came to the Prophet (ﷺ) and said, "O Allah's Apostle! I have lost my eyesight and I lead my people in the prayer (as an Imam). When it rains, the valley which is between me and my people, flows with water, and then I cannot go to their mosque to lead them in the prayer. O Allah's Messenger (ﷺ)! I wish that you could come and pray in my house so that I may take it as a praying place. The Prophet (ﷺ) said, "Allah willing, I will do that." The next morning, soon after the sun had risen, Allah's Messenger (ﷺ) came with Abu Bakr. The Prophet (ﷺ) asked for the permission to enter and I admitted him. The Prophet (ﷺ) had not sat till he had entered the house and said to me, "Where do you like me to pray in your house?" I pointed at a place in my house whereupon he stood and said, "Allahu Akbar." We lined behind him and he prayed two rak`at and finished it with Taslim. We then requested him to stay for a special meal of Khazira which we had prepared. A large number of men from the adjoining area gathered in the house. One of them said, "Where is Malik bin Ad-Dukhshun?" Another man said, "He is a hypocrite and does not love Allah and His Apostle." The Prophet said, "Do not say so. Do you not think that he has said: "None has the right to be worshipped but Allah," seeking Allah's pleasure? The man said, "Allah and His Apostle know better, but we have always seen him mixing with hypocrites and giving them advice." The Prophet (ﷺ) said, "Allah has forbidden the (Hell) Fire for those who testify that none has the right to be worshipped but Allah, seeking Allah's pleasure}}
\hadithdefcmd{bukhari}{5402}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ أَهْدَتْ خَالَتِي إِلَى النَّبِيِّ صلى الله عليه وسلم ضِبَابًا وَأَقِطًا وَلَبَنًا، فَوُضِعَ الضَّبُّ عَلَى مَائِدَتِهِ، فَلَوْ كَانَ حَرَامًا لَمْ يُوضَعْ وَشَرِبَ اللَّبَنَ، وَأَكَلَ الأَقِطَ‏.‏\hadithno{5402}\hadithtrans{Narrated Ibn `Abbas:My aunt presented (roasted) mastigures, Iqt and milk to the Prophet (ﷺ) . The mastigures were put on his dining sheet, and if it was unlawful to eat, it would not have been put there. The Prophet (ﷺ) drank the milk and ate the Iqt only}}
\hadithdefcmd{bukhari}{5403}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ إِنْ كُنَّا لَنَفْرَحُ بِيَوْمِ الْجُمُعَةِ، كَانَتْ لَنَا عَجُوزٌ تَأْخُذُ أُصُولَ السِّلْقِ، فَتَجْعَلُهُ فِي قِدْرٍ لَهَا، فَتَجْعَلُ فِيهِ حَبَّاتٍ مِنْ شَعِيرٍ، إِذَا صَلَّيْنَا زُرْنَاهَا فَقَرَّبَتْهُ إِلَيْنَا، وَكُنَّا نَفْرَحُ بِيَوْمِ الْجُمُعَةِ مِنْ أَجْلِ ذَلِكَ، وَمَا كُنَّا نَتَغَدَّى وَلاَ نَقِيلُ إِلاَّ بَعْدَ الْجُمُعَةِ، وَاللَّهِ مَا فِيهِ شَحْمٌ وَلاَ وَدَكٌ‏.‏\hadithno{5403}\hadithtrans{Narrated Sahl bin Sa`d:We used to be happy on Fridays, for there was an old lady who used to pull out the roots of Silq and put it in a cooking pot with some barley. When we had finished the prayer, we would visit her and she would present that dish before us. So we used to be happy on Fridays because of that, and we never used to take our meals or have a mid-day nap except after the Friday prayer. By Allah, that meal contained no fat}}
\hadithdefcmd{bukhari}{5404}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ تَعَرَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَتِفًا، ثُمَّ قَامَ فَصَلَّى، وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{5404}\hadithtrans{Narrated Ibn 'Abbas: The Prophet (ﷺ) ate of the meat of a shoulder (by cutting the meat with his teeth), and then got up and offered the prayer without performing the ablution anew}}
\hadithdefcmd{bukhari}{5405}{وَعَنْ أَيُّوبَ، وَعَاصِمٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ انْتَشَلَ النَّبِيُّ صلى الله عليه وسلم عَرْقًا مِنْ قِدْرٍ فَأَكَلَ، ثُمَّ صَلَّى، وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{5405}\hadithtrans{Narrated Ibn 'Abbas:The Prophet (ﷺ) took out a bone with meat on it from a cooking pot and ate of it, and then offered the prayer without performing ablution anew}}
\hadithdefcmd{bukhari}{5406}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا فُلَيْحٌ، حَدَّثَنَا أَبُو حَازِمٍ الْمَدَنِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم نَحْوَ مَكَّةَ‏.‏\hadithno{5406}\hadithtrans{Narrated Abu Qatada:We went out towards Mecca with the Prophet}}
\hadithdefcmd{bukhari}{5407}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ أَبِي حَازِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ السَّلَمِيِّ، عَنْ أَبِيهِ، أَنَّهُ قَالَ كُنْتُ يَوْمًا جَالِسًا مَعَ رِجَالٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فِي مَنْزِلٍ فِي طَرِيقِ مَكَّةَ، وَرَسُولُ اللَّهِ صلى الله عليه وسلم نَازِلٌ أَمَامَنَا، وَالْقَوْمُ مُحْرِمُونَ وَأَنَا غَيْرُ مُحْرِمٍ، فَأَبْصَرُوا حِمَارًا وَحْشِيًّا وَأَنَا مَشْغُولٌ أَخْصِفُ نَعْلِي، فَلَمْ يُؤْذِنُونِي لَهُ، وَأَحَبُّوا لَوْ أَنِّي أَبْصَرْتُهُ، فَالْتَفَتُّ فَأَبْصَرْتُهُ فَقُمْتُ إِلَى الْفَرَسِ فَأَسْرَجْتُهُ‏.‏ ثُمَّ رَكِبْتُ وَنَسِيتُ السَّوْطَ وَالرُّمْحَ فَقُلْتُ لَهُمْ نَاوِلُونِي السَّوْطَ وَالرُّمْحَ‏.‏ فَقَالُوا لاَ وَاللَّهِ لاَ نُعِينُكَ عَلَيْهِ بِشَىْءٍ‏.‏ فَغَضِبْتُ فَنَزَلْتُ فَأَخَذْتُهُمَا، ثُمَّ رَكِبْتُ فَشَدَدْتُ عَلَى الْحِمَارِ فَعَقَرْتُهُ، ثُمَّ جِئْتُ بِهِ وَقَدْ مَاتَ فَوَقَعُوا فِيهِ يَأْكُلُونَهُ، ثُمَّ إِنَّهُمْ شَكُّوا فِي أَكْلِهِمْ إِيَّاهُ وَهُمْ حُرُمٌ، فَرُحْنَا وَخَبَأْتُ الْعَضُدَ مَعِي، فَأَدْرَكْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلْنَاهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ مَعَكُمْ مِنْهُ شَىْءٌ ‏"‏‏.‏ فَنَاوَلْتُهُ الْعَضُدَ فَأَكَلَهَا حَتَّى تَعَرَّقَهَا، وَهْوَ مُحْرِمٌ‏.‏ قَالَ ابْنُ جَعْفَرٍ وَحَدَّثَنِي زَيْدُ بْنُ أَسْلَمَ عَنْ عَطَاءِ بْنِ يَسَارٍ عَنْ أَبِي قَتَادَةَ مِثْلَهُ‏.‏\hadithno{5407}\hadithtrans{Narrated Abu Qatada:Once, while I was sitting with the companions of the Prophet (ﷺ) at a station on the road to Mecca and Allah's Messenger (ﷺ) was stationing ahead of us and all the people were assuming Ihram while I was not. My companion, saw an onager while I was busy Mending my shoes. They did not Inform me of the onager but they wished that I would see it Suddenly I looked and saw the onager Then I headed towards my horse, saddled it and rode, but I forgot to take the lash and the spear. So I said to them my companions), "Give me the lash and the spear." But they said, "No, by Allah we will not help you in any way to hunt it ' I got angry, dismounted, took it the spear and the lash), rode (the horse chased the onager and wounded it Then I brought it when it had dyed. My companions started eating of its (cooked) meat, but they suspected that it might be unlawful to eat of its meat while they were in a state of Ihram Then I proceeded further and I kept one of its forelegs with me. When we met Allah's Apostle we asked him about that. He said, "Have you some of its meat with you?" I gave him that foreleg and he ate the meat till he stripped the bone of its flesh although he was in a state of Ihram}}
\hadithdefcmd{bukhari}{5408}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي جَعْفَرُ بْنُ عَمْرِو بْنِ أُمَيَّةَ، أَنَّ أَبَاهُ، عَمْرَو بْنَ أُمَيَّةَ أَخْبَرَهُ أَنَّهُ، رَأَى النَّبِيَّ صلى الله عليه وسلم يَحْتَزُّ مِنْ كَتِفِ شَاةٍ فِي يَدِهِ، فَدُعِيَ إِلَى الصَّلاَةِ فَأَلْقَاهَا وَالسِّكِّينَ الَّتِي يَحْتَزُّ بِهَا، ثُمَّ قَامَ فَصَلَّى، وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{5408}\hadithtrans{Narrated `Amr bin Umaiyya:that he saw the Prophet (ﷺ) holding a shoulder piece of mutton in his hand and cutting part of it with a knife. Then he was called for the prayer whereupon he put down the shoulder piece and the knife with which he was cutting it, and then stood for prayer without performing ablution again}}
\hadithdefcmd{bukhari}{5409}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَا عَابَ النَّبِيُّ صلى الله عليه وسلم طَعَامًا قَطُّ، إِنِ اشْتَهَاهُ أَكَلَهُ، وَإِنْ كَرِهَهُ تَرَكَهُ‏.‏\hadithno{5409}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) never criticized any food (he was invited to) but he used to eat if he liked the food, and leave it if he disliked it}}
\hadithdefcmd{bukhari}{5410}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، أَنَّهُ سَأَلَ سَهْلاً هَلْ رَأَيْتُمْ فِي زَمَانِ النَّبِيِّ صلى الله عليه وسلم النَّقِيَّ قَالَ لاَ‏.‏ فَقُلْتُ فَهَلْ كُنْتُمْ تَنْخُلُونَ الشَّعِيرَ قَالَ لاَ وَلَكِنْ كُنَّا نَنْفُخُهُ‏.‏\hadithno{5410}\hadithtrans{Narrated Abu Hazim:that he asked Sahl, "Did you use white flour during the lifetime of the Prophet (ﷺ) ?" Sahl replied, "No. Hazim asked, "Did you use to sift barley flour?" He said, "No, but we used to blow off the husk (of the barley)}}
\hadithdefcmd{bukhari}{5411}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَبَّاسٍ الْجُرَيْرِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَسَمَ النَّبِيُّ صلى الله عليه وسلم يَوْمًا بَيْنَ أَصْحَابِهِ تَمْرًا، فَأَعْطَى كُلَّ إِنْسَانٍ سَبْعَ تَمَرَاتٍ، فَأَعْطَانِي سَبْعَ تَمَرَاتٍ إِحْدَاهُنَّ حَشَفَةٌ، فَلَمْ يَكُنْ فِيهِنَّ تَمْرَةٌ أَعْجَبَ إِلَىَّ مِنْهَا، شَدَّتْ فِي مَضَاغِي‏.‏\hadithno{5411}\hadithtrans{Narrated Abu Huraira:Once the Prophet (ﷺ) distributed dates among his companions and gave each one seven dates. He gave me seven dates too, one of which was dry and hard, but none of the other dates was more liked by me than that one, for it prolonged my chewing it}}
\hadithdefcmd{bukhari}{5412}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ سَعْدٍ، قَالَ رَأَيْتُنِي سَابِعَ سَبْعَةٍ مَعَ النَّبِيِّ صلى الله عليه وسلم مَا لَنَا طَعَامٌ إِلاَّ وَرَقُ الْحُبْلَةِ ـ أَوِ الْحَبَلَةِ ـ حَتَّى يَضَعَ أَحَدُنَا مَا تَضَعُ الشَّاةُ، ثُمَّ أَصْبَحَتْ بَنُو أَسَدٍ تُعَزِّرُنِي عَلَى الإِسْلاَمِ، خَسِرْتُ إِذًا وَضَلَّ سَعْيِي‏.‏\hadithno{5412}\hadithtrans{Narrated Sa`d:I was one of (the first) seven (who had embraced Islam) with Allah's Messenger (ﷺ) and we had nothing to eat then, except the leaves of the Habala or Hubula tree, so that our stool used to be similar to that of sheep. Now the tribe of Bani Asad wants to teach me Islam; I would be a loser and all my efforts would be in vain (if I learn Islam anew from them)}}
\hadithdefcmd{bukhari}{5413}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، عَنْ أَبِي حَازِمٍ، قَالَ سَأَلْتُ سَهْلَ بْنَ سَعْدٍ فَقُلْتُ هَلْ أَكَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّقِيَّ فَقَالَ سَهْلٌ مَا رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم النَّقِيَّ مِنْ حِينَ ابْتَعَثَهُ اللَّهُ حَتَّى قَبَضَهُ اللَّهُ‏.‏ قَالَ فَقُلْتُ هَلْ كَانَتْ لَكُمْ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم مَنَاخِلُ قَالَ مَا رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم مُنْخُلاً مِنْ حِينَ ابْتَعَثَهُ اللَّهُ حَتَّى قَبَضَهُ‏.‏ قَالَ قُلْتُ كَيْفَ كُنْتُمْ تَأْكُلُونَ الشَّعِيرَ غَيْرَ مَنْخُولٍ قَالَ كُنَّا نَطْحَنُهُ وَنَنْفُخُهُ، فَيَطِيرُ مَا طَارَ وَمَا بَقِيَ ثَرَّيْنَاهُ فَأَكَلْنَاهُ‏.‏\hadithno{5413}\hadithtrans{Narrated Abu Hazim:I asked Sahl bin Sa`d, "Did Allah's Messenger (ﷺ) ever eat white flour?" Sahl said, "Allah's Messenger (ﷺ) never saw white flour since Allah sent him as an Apostle till He took him unto Him." I asked, "Did the people have (use) sieves during the lifetime of Allah's Messenger (ﷺ)?" Sahl said, "Allah's Messenger (ﷺ) never saw (used) a sieve since Allah sent him as an Apostle until He took him unto Him," I said, "How could you eat barley unsifted?" he said, "We used to grind it and then blow off its husk, and after the husk flew away, we used to prepare the dough (bake) and eat it}}
\hadithdefcmd{bukhari}{5414}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ مَرَّ بِقَوْمٍ بَيْنَ أَيْدِيهِمْ شَاةٌ مَصْلِيَّةٌ، فَدَعَوْهُ فَأَبَى أَنْ يَأْكُلَ قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الدُّنْيَا وَلَمْ يَشْبَعْ مِنَ الْخُبْزِ الشَّعِيرِ‏.‏\hadithno{5414}\hadithtrans{Narrated Abu Huraira:that he passed by a group of people in front of whom there was a roasted sheep. They invited him but he refused to eat and said, "Allah's Messenger (ﷺ) left this world without satisfying his hunger even with barley bread}}
\hadithdefcmd{bukhari}{5415}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا مُعَاذٌ، حَدَّثَنِي أَبِي، عَنْ يُونُسَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَا أَكَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى خِوَانٍ، وَلاَ فِي سُكْرُجَةٍ، وَلاَ خُبِزَ لَهُ مُرَقَّقٌ‏.‏ قُلْتُ لِقَتَادَةَ عَلَى مَا يَأْكُلُونَ قَالَ عَلَى السُّفَرِ‏.‏\hadithno{5415}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) never took his meals at a dining table, nor in small plates, and he never ate thin wellbaked bread. (The sub-narrator asked Qatada, "Over what did they use to take their meals?" Qatada said, "On leather dining sheets)}}
\hadithdefcmd{bukhari}{5416}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا شَبِعَ آلُ مُحَمَّدٍ صلى الله عليه وسلم مُنْذُ قَدِمَ الْمَدِينَةَ مِنْ طَعَامِ الْبُرِّ ثَلاَثَ لَيَالٍ تِبَاعًا، حَتَّى قُبِضَ‏.‏\hadithno{5416}\hadithtrans{Narrated `Aisha:The family of Muhammad had not eaten wheat bread to their satisfaction for three consecutive days since his arrival at Medina till he died}}
\hadithdefcmd{bukhari}{5417}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا كَانَتْ إِذَا مَاتَ الْمَيِّتُ مِنْ أَهْلِهَا فَاجْتَمَعَ لِذَلِكَ النِّسَاءُ، ثُمَّ تَفَرَّقْنَ، إِلاَّ أَهْلَهَا وَخَاصَّتَهَا، أَمَرَتْ بِبُرْمَةٍ مِنْ تَلْبِينَةٍ فَطُبِخَتْ، ثُمَّ صُنِعَ ثَرِيدٌ فَصُبَّتِ التَّلْبِينَةُ عَلَيْهَا ثُمَّ قَالَتْ كُلْنَ مِنْهَا فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ التَّلْبِينَةُ مَجَمَّةٌ لِفُؤَادِ الْمَرِيضِ، تَذْهَبُ بِبَعْضِ الْحُزْنِ ‏"‏‏.‏\hadithno{5417}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) that whenever one of her relatives died, the women assembled and then dispersed (returned to their houses) except her relatives and close friends. She would order that a pot of Talbina be cooked. Then Tharid (a dish prepared from meat and bread) would be prepared and the Talbina would be poured on it. `Aisha would say (to the women),"Eat of it, for I heard Allah's Messenger (ﷺ) saying, 'The Talbina soothes the heart of the patient and relieves him from some of his sadness}}
\hadithdefcmd{bukhari}{5418}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ الْجَمَلِيِّ، عَنْ مُرَّةَ الْهَمْدَانِيِّ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ كَمَلَ مِنَ الرِّجَالِ كَثِيرٌ، وَلَمْ يَكْمُلْ مِنَ النِّسَاءِ إِلاَّ مَرْيَمُ بِنْتُ عِمْرَانَ وَآسِيَةُ امْرَأَةُ فِرْعَوْنَ، وَفَضْلُ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ ‏"‏‏.‏\hadithno{5418}\hadithtrans{Narrated Abu Musa Al-Ash`ari:The Prophet (ﷺ) said, "Many men reached perfection but none among the women reached perfection except Mary, the daughter of ' `Imran, and Asia, Pharoah's wife. And the superiority of `Aisha to other women is like the superiority of Tharid to other kinds of food}}
\hadithdefcmd{bukhari}{5419}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي طُوَالَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فَضْلُ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ ‏"‏‏.‏\hadithno{5419}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "The superiority of `Aisha to other women is like the superiority of Tharid to other kinds of food}}
\hadithdefcmd{bukhari}{5420}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ أَبَا حَاتِمٍ الأَشْهَلَ بْنَ حَاتِمٍ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ ثُمَامَةَ بْنِ أَنَسٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ دَخَلْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم عَلَى غُلاَمٍ لَهُ خَيَّاطٍ، فَقَدَّمَ إِلَيْهِ قَصْعَةً فِيهَا ثَرِيدٌ ـ قَالَ ـ وَأَقْبَلَ عَلَى عَمَلِهِ ـ قَالَ ـ فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يَتَتَبَّعُ الدُّبَّاءَ ـ قَالَ ـ فَجَعَلْتُ أَتَتَبَّعُهُ فَأَضَعُهُ بَيْنَ يَدَيْهِ ـ قَالَ ـ فَمَا زِلْتُ بَعْدُ أُحِبُّ الدُّبَّاءَ‏.‏\hadithno{5420}\hadithtrans{Narrated Anas:I went along with the Prophet (ﷺ) to the house of a young tailor of his. The tailor presented a dish of Tharid to the Prophet (ﷺ) and resumed his work. The Prophet (ﷺ) started picking the pieces of gourd and I too, started picking them and putting it before him. Since then I have always loved (to eat) gourd}}
\hadithdefcmd{bukhari}{5421}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، عَنْ قَتَادَةَ، قَالَ كُنَّا نَأْتِي أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ وَخَبَّازُهُ قَائِمٌ قَالَ كُلُوا فَمَا أَعْلَمُ النَّبِيَّ صلى الله عليه وسلم رَأَى رَغِيفًا مُرَقَّقًا حَتَّى لَحِقَ بِاللَّهِ، وَلاَ رَأَى شَاةً سَمِيطًا بِعَيْنِهِ قَطُّ‏.‏\hadithno{5421}\hadithtrans{Narrated Qatada:We used to visit Anas bin Malik while his baker was standing (and baking). Anas would say, "Eat! I do not know that the Prophet (ﷺ) had ever seen well-baked bread till he met Allah, nor had he ever seen a roasted sheep with his own eyes}}
\hadithdefcmd{bukhari}{5422}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ أُمَيَّةَ الضَّمْرِيِّ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَحْتَزُّ مِنْ كَتِفِ شَاةٍ، فَأَكَلَ مِنْهَا، فَدُعِيَ إِلَى الصَّلاَةِ، فَقَامَ فَطَرَحَ السِّكِّينَ فَصَلَّى، وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{5422}\hadithtrans{Narrated `Amr bin Umaiyay Ad-Damri:I saw Allah's Messenger (ﷺ) cutting part of the shoulder of mutton with a knife. He ate of it and then was called for prayer whereupon he got up and put down the knife and offered the prayer without performing new ablution}}
\hadithdefcmd{bukhari}{5423}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، عَنْ أَبِيهِ، قَالَ قُلْتُ لِعَائِشَةَ أَنَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ تُؤْكَلَ لُحُومُ الأَضَاحِيِّ فَوْقَ ثَلاَثٍ قَالَتْ مَا فَعَلَهُ إِلاَّ فِي عَامٍ جَاعَ النَّاسُ فِيهِ، فَأَرَادَ أَنْ يُطْعِمَ الْغَنِيُّ الْفَقِيرَ، وَإِنْ كُنَّا لَنَرْفَعُ الْكُرَاعَ فَنَأْكُلُهُ بَعْدَ خَمْسَ عَشْرَةَ‏.‏ قِيلَ مَا اضْطَرَّكُمْ إِلَيْهِ فَضَحِكَتْ قَالَتْ مَا شَبِعَ آلُ مُحَمَّدٍ صلى الله عليه وسلم مِنْ خُبْزِ بُرٍّ مَأْدُومٍ ثَلاَثَةَ أَيَّامٍ حَتَّى لَحِقَ بِاللَّهِ‏.‏ وَقَالَ ابْنُ كَثِيرٍ أَخْبَرَنَا سُفْيَانُ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَابِسٍ بِهَذَا‏.‏\hadithno{5423}\hadithtrans{Narrated `Abis:I asked `Aisha "Did the Prophet (ﷺ) forbid eating the meat of sacrifices offered on `Id-ul-Adha for more than three days" She said, "The Prophet (ﷺ) did not do this except in the year when the people were hungry, so he wanted the rich to feed the poor. But later we used to store even a trotter of a sheep to eat it fifteen days later." She was asked, "What compelled you to do so?" She smiled and said, "The family of Muhammad did not eat to their satisfaction white bread with meat soup for three successive days till he met Allah}}
\hadithdefcmd{bukhari}{5424}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَتَزَوَّدُ لُحُومَ الْهَدْىِ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم إِلَى الْمَدِينَةِ‏.‏ تَابَعَهُ مُحَمَّدٌ عَنِ ابْنِ عُيَيْنَةَ‏.‏ وَقَالَ ابْنُ جُرَيْجٍ قُلْتُ لِعَطَاءٍ أَقَالَ حَتَّى جِئْنَا الْمَدِينَةَ قَالَ لاَ‏.‏\hadithno{5424}\hadithtrans{Narrated Jabir:We used to carry the meat of the Hadis (sacrificed animals) to Medina during the life-time of the Prophet}}
\hadithdefcmd{bukhari}{5425}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، مَوْلَى الْمُطَّلِبِ بْنِ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَبِي طَلْحَةَ ‏"‏ الْتَمِسْ غُلاَمًا مِنْ غِلْمَانِكُمْ يَخْدُمُنِي ‏"‏‏.‏ فَخَرَجَ بِي أَبُو طَلْحَةَ، يُرْدِفُنِي وَرَاءَهُ، فَكُنْتُ أَخْدُمُ رَسُولَ اللَّهِ صلى الله عليه وسلم كُلَّمَا نَزَلَ، فَكُنْتُ أَسْمَعُهُ يُكْثِرُ أَنْ يَقُولَ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْحَزَنِ، وَالْعَجْزِ وَالْكَسَلِ، وَالْبُخْلِ وَالْجُبْنِ وَضَلَعِ الدَّيْنِ، وَغَلَبَةِ الرِّجَالِ ‏"‏‏.‏ فَلَمْ أَزَلْ أَخْدُمُهُ حَتَّى أَقْبَلْنَا مِنْ خَيْبَرَ، وَأَقْبَلَ بِصَفِيَّةَ بِنْتِ حُيَىٍّ قَدْ حَازَهَا، فَكُنْتُ أَرَاهُ يُحَوِّي وَرَاءَهُ بِعَبَاءَةٍ أَوْ بِكِسَاءٍ، ثُمَّ يُرْدِفُهَا وَرَاءَهُ، حَتَّى إِذَا كُنَّا بِالصَّهْبَاءِ صَنَعَ حَيْسًا فِي نِطَعٍ، ثُمَّ أَرْسَلَنِي فَدَعَوْتُ رِجَالاً فَأَكَلُوا، وَكَانَ ذَلِكَ بِنَاءَهُ بِهَا، ثُمَّ أَقْبَلَ حَتَّى إِذَا بَدَا لَهُ أُحُدٌ قَالَ ‏"‏ هَذَا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏‏.‏ فَلَمَّا أَشْرَفَ عَلَى الْمَدِينَةِ قَالَ ‏"‏ اللَّهُمَّ إِنِّي أُحَرِّمُ مَا بَيْنَ جَبَلَيْهَا مِثْلَ مَا حَرَّمَ بِهِ إِبْرَاهِيمُ مَكَّةَ، اللَّهُمَّ بَارِكْ لَهُمْ فِي مُدِّهِمْ وَصَاعِهِمْ ‏"‏‏.‏\hadithno{5425}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said to Abu Talha, "Seek one of your boys to serve me." Abu Talha mounted me behind him (on his riding animal) and took me (to the Prophet (ﷺ) ). So I used to serve Allah's Messenger (ﷺ) whenever he dismounted (to stay somewhere). I used to hear him saying very often, "O Allah! I seek refuge with You from, having worries sadness, helplessness, laziness, miserliness, cowardice, from being heavily in debt and from being overpowered by other persons unjustly." I kept on serving till we -returned from the battle of Khaibar. The Prophet (ﷺ) then brought Safiyya bint Huyai whom he had won from the war booty. I saw him folding up a gown or a garment for her to sit on behind him (on his she-camel). When he reached As-Sahba', he prepared Hais and placed it on a dining sheet. Then he sent me to invite men, who (came and) ate; and that was his and Safiyya's wedding banquet. Then the Prophet proceeded, and when he saw (noticed) the mountain of Uhud, he said, "This mountain loves us, and we love it." When we approached Medina, he said, "O Allah! I make the area between its two mountains a sanctuary as Abraham has made Mecca a sanctuary. O Allah! Bless their Mudd and Sa (special kinds of measure)}}
\hadithdefcmd{bukhari}{5426}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سَيْفُ بْنُ أَبِي سُلَيْمَانَ، قَالَ سَمِعْتُ مُجَاهِدًا، يَقُولُ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى، أَنَّهُمْ كَانُوا عِنْدَ حُذَيْفَةَ فَاسْتَسْقَى فَسَقَاهُ مَجُوسِيٌّ‏.‏ فَلَمَّا وَضَعَ الْقَدَحَ فِي يَدِهِ رَمَاهُ بِهِ وَقَالَ لَوْلاَ أَنِّي نَهَيْتُهُ غَيْرَ مَرَّةٍ وَلاَ مَرَّتَيْنِ‏.‏ كَأَنَّهُ يَقُولُ لَمْ أَفْعَلْ هَذَا، وَلَكِنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَلْبَسُوا الْحَرِيرَ وَلاَ الدِّيبَاجَ وَلاَ تَشْرَبُوا فِي آنِيَةِ الذَّهَبِ وَالْفِضَّةِ، وَلاَ تَأْكُلُوا فِي صِحَافِهَا، فَإِنَّهَا لَهُمْ فِي الدُّنْيَا وَلَنَا فِي الآخِرَةِ ‏"‏‏.‏\hadithno{5426}\hadithtrans{Narrated `Abdur-Rahman bin Abi Laila:We were sitting in the company of Hudhaifa who asked for water and a Magian brought him water. But when he placed the cup in his hand, he threw it at him and said, "Had I not forbidden him to do so more than once or twice?" He wanted to say, "I would not have done so," adding, "but I heard the Prophet saying, "Do not wear silk or Dibaja, and do not drink in silver or golden vessels, and do not eat in plates of such metals, for such things are for the unbelievers in this worldly life and for us in the Hereafter}}
\hadithdefcmd{bukhari}{5427}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏مَثَلُ الْمُؤْمِنِ الَّذِي يَقْرَأُ الْقُرْآنَ كَمَثَلِ الأُتْرُجَّةِ، رِيحُهَا طَيِّبٌ وَطَعْمُهَا طَيِّبٌ، وَمَثَلُ الْمُؤْمِنِ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ كَمَثَلِ التَّمْرَةِ لاَ رِيحَ لَهَا وَطَعْمُهَا حُلْوٌ، وَمَثَلُ الْمُنَافِقِ الَّذِي يَقْرَأُ الْقُرْآنَ مَثَلُ الرَّيْحَانَةِ، رِيحُهَا طَيِّبٌ وَطَعْمُهَا مُرٌّ، وَمَثَلُ الْمُنَافِقِ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ كَمَثَلِ الْحَنْظَلَةِ، لَيْسَ لَهَا رِيحٌ وَطَعْمُهَا مُرٌّ ‏"‏‏.‏\hadithno{5427}\hadithtrans{Narrated Abu Musa Al-Ash`ari:Allah's Messenger (ﷺ) said, "The example of a Believer who recites the Qur'an, is that of a citron which smells good and tastes good; And the example of a Believer who does not recite the Qur'an, is that of a date which has no smell but tastes sweet; and the example of a hypocrite who recites the Qur'an, is that of an aromatic plant which smells good but tastes bitter; and the example of a hypocrite who does not recite the Qur'an, is that of a colocynth plant which has no smell and is bitter in taste}}
\hadithdefcmd{bukhari}{5428}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فَضْلُ عَائِشَةَ عَلَى النِّسَاءِ كَفَضْلِ الثَّرِيدِ عَلَى سَائِرِ الطَّعَامِ ‏"‏‏.‏\hadithno{5428}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "The superiority of `Aisha to other ladies is like the superiority of Tharid to other kinds of food}}
\hadithdefcmd{bukhari}{5429}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ السَّفَرُ قِطْعَةٌ مِنَ الْعَذَابِ، يَمْنَعُ أَحَدَكُمْ نَوْمَهُ وَطَعَامَهُ، فَإِذَا قَضَى نَهْمَتَهُ مِنْ وَجْهِهِ فَلْيُعَجِّلْ إِلَى أَهْلِهِ ‏"‏‏.‏\hadithno{5429}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Traveling is a kind of torture, as it prevents one from sleeping and eating! So when one has finished his job, he should return quickly to his family}}
\hadithdefcmd{bukhari}{5430}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ رَبِيعَةَ، أَنَّهُ سَمِعَ الْقَاسِمَ بْنَ مُحَمَّدٍ، يَقُولُ كَانَ فِي بَرِيرَةَ ثَلاَثُ سُنَنٍ، أَرَادَتْ عَائِشَةُ أَنْ تَشْتَرِيَهَا فَتُعْتِقَهَا، فَقَالَ أَهْلُهَا، وَلَنَا الْوَلاَءُ، فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ لَوْ شِئْتِ شَرَطْتِيهِ لَهُمْ، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ قَالَ وَأُعْتِقَتْ فَخُيِّرَتْ فِي أَنْ تَقِرَّ تَحْتَ زَوْجِهَا أَوْ تُفَارِقَهُ، وَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا بَيْتَ عَائِشَةَ وَعَلَى النَّارِ بُرْمَةٌ تَفُورُ، فَدَعَا بِالْغَدَاءِ فَأُتِيَ بِخُبْزٍ وَأُدْمٍ مِنْ أُدْمِ الْبَيْتِ فَقَالَ ‏"‏ أَلَمْ أَرَ لَحْمًا ‏"‏‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ، وَلَكِنَّهُ لَحْمٌ تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ، فَأَهْدَتْهُ لَنَا‏.‏ فَقَالَ‏"‏ هُوَ صَدَقَةٌ عَلَيْهَا، وَهَدِيَّةٌ لَنَا ‏"‏‏.‏\hadithno{5430}\hadithtrans{Narrated Qasim bin Muhammad:Three traditions have been established because of Barira: `Aisha intended to buy her and set her free, but Barira's masters said, "Her wala' will be for us." `Aisha mentioned that to Allah's Messenger (ﷺ) who said, "You could accept their condition if you wished, for the wala is for the one who manumits the slave." Barira was manumitted, then she was given the choice either to stay with her husband or leave him; One day Allah's Messenger (ﷺ) entered `Aisha's house while there was a cooking pot of food boiling on the fire. The Prophet (ﷺ) asked for lunch, and he was presented with bread and some extra food from the home-made Udm (e.g. soup). He asked, "Don't I see meat (being cooked)?" They said, "Yes, O Allah's Apostle! But it is the meat that has been given to Barira in charity and she has given it to us as a present." He said, "For Barira it is alms, but for us it is a present}}
\hadithdefcmd{bukhari}{5431}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، عَنْ أَبِي أُسَامَةَ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ الْحَلْوَاءَ وَالْعَسَلَ‏.‏\hadithno{5431}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to love sweet edible things and honey}}
\hadithdefcmd{bukhari}{5432}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ شَيْبَةَ، قَالَ أَخْبَرَنِي ابْنُ أَبِي الْفُدَيْكِ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كُنْتُ أَلْزَمُ النَّبِيَّ صلى الله عليه وسلم لِشِبَعِ بَطْنِي حِينَ لاَ آكُلُ الْخَمِيرَ، وَلاَ أَلْبَسُ الْحَرِيرَ، وَلاَ يَخْدُمُنِي فُلاَنٌ وَلاَ فُلاَنَةُ، وَأُلْصِقُ بَطْنِي بِالْحَصْبَاءِ، وَأَسْتَقْرِئُ الرَّجُلَ الآيَةَ وَهْىَ مَعِي كَىْ يَنْقَلِبَ بِي فَيُطْعِمَنِي، وَخَيْرُ النَّاسِ لِلْمَسَاكِينِ جَعْفَرُ بْنُ أَبِي طَالِبٍ، يَنْقَلِبُ بِنَا فَيُطْعِمُنَا مَا كَانَ فِي بَيْتِهِ، حَتَّى إِنْ كَانَ لَيُخْرِجُ إِلَيْنَا الْعُكَّةَ لَيْسَ فِيهَا شَىْءٌ، فَنَشْتَقُّهَا فَنَلْعَقُ مَا فِيهَا‏.‏\hadithno{5432}\hadithtrans{Narrated Abu Huraira:I used to accompany Allah's Messenger (ﷺ) to fill my stomach; and that was when I did not eat baked bread, nor wear silk. Neither a male nor a female slave used to serve me, and I used to bind stones over my belly and ask somebody to recite a Qur'anic Verse for me though I knew it, so that he might take me to his house and feed me. Ja`far bin Abi Talib was very kind to the poor, and he used to take us and feed us with what ever was available in his house, (and if nothing was available), he used to give us the empty (honey or butter) skin which we would tear and lick whatever was in it}}
\hadithdefcmd{bukhari}{5433}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا أَزْهَرُ بْنُ سَعْدٍ، عَنِ ابْنِ عَوْنٍ، عَنْ ثُمَامَةَ بْنِ أَنَسٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى مَوْلًى لَهُ خَيَّاطًا، فَأُتِيَ بِدُبَّاءٍ، فَجَعَلَ يَأْكُلُهُ، فَلَمْ أَزَلْ أُحِبُّهُ مُنْذُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْكُلُهُ‏.‏\hadithno{5433}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) went to (the house of) his slave tailor, and he was offered (a dish of) gourd of which he started eating. I have loved to eat gourd since I saw Allah's Messenger (ﷺ) eating it}}
\hadithdefcmd{bukhari}{5434}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ كَانَ مِنَ الأَنْصَارِ رَجُلٌ يُقَالُ لَهُ أَبُو شُعَيْبٍ، وَكَانَ لَهُ غُلاَمٌ لَحَّامٌ فَقَالَ اصْنَعْ لِي طَعَامًا أَدْعُو رَسُولَ اللَّهِ صلى الله عليه وسلم خَامِسَ خَمْسَةٍ، فَدَعَا رَسُولَ اللَّهِ صلى الله عليه وسلم خَامِسَ خَمْسَةٍ، فَتَبِعَهُمْ رَجُلٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّكَ دَعَوْتَنَا خَامِسَ خَمْسَةٍ وَهَذَا رَجُلٌ قَدْ تَبِعَنَا، فَإِنْ شِئْتَ أَذِنْتَ لَهُ، وَإِنْ شِئْتَ تَرَكْتَهُ ‏"‏‏.‏ قَالَ بَلْ أَذِنْتُ لَهُ‏.‏ قَالَ مُحَمَّدُ بْنُ يُوسُفَ سَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيْلَ يَقُولُ إِذَا كَانَ الْقَوْمُ عَلَى الْمَائِدَةِ لَيْسَ لَهُمْ أَنْ يُنَاوِلُوا مِنْ مَائِدَةٍ إِلَى مَائِدَةٍ أُخْرَى وَلَكِنْ يُنَاوِلُ بَعْضُهُمْ بَعْضًا فِي تِلْكَ الْمَائِدَةِ أَوْ يَدَعُ\hadithno{5434}\hadithtrans{Narrated Abu Mas`ud Al-Ansari:There was a man called Abu Shu'aib, and he had a slave who was a butcher. He said (to his slave), "Prepare a meal to which I may invite Allah's Messenger (ﷺ) along with four other men." So he invited Allah's Messenger (ﷺ) and four other men, but another man followed them whereupon the Prophet (ﷺ) said, "You have invited me as one of five guests, but now another man has followed us. If you wish you can admit him, and if you wish you can refuse him." On that the host said, "But I admit him." Narrated Muhammad bin Isma`il: If guests are sitting at a dining table, they do not have the right to carry food from other tables to theirs, but they can pass on food from their own table to each other; otherwise they should leave it}}
\hadithdefcmd{bukhari}{5435}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ النَّضْرَ، أَخْبَرَنَا ابْنُ عَوْنٍ، قَالَ أَخْبَرَنِي ثُمَامَةُ بْنُ عَبْدِ اللَّهِ بْنِ أَنَسٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كُنْتُ غُلاَمًا أَمْشِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى غُلاَمٍ لَهُ خَيَّاطٍ، فَأَتَاهُ بِقَصْعَةٍ فِيهَا طَعَامٌ وَعَلَيْهِ دُبَّاءٌ، فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَتَبَّعُ الدُّبَّاءَ ـ قَالَ ـ فَلَمَّا رَأَيْتُ ذَلِكَ جَعَلْتُ أَجْمَعُهُ بَيْنَ يَدَيْهِ ـ قَالَ ـ فَأَقْبَلَ الْغُلاَمُ عَلَى عَمَلِهِ‏.‏ قَالَ أَنَسٌ لاَ أَزَالُ أُحِبُّ الدُّبَّاءَ بَعْدَ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَنَعَ مَا صَنَعَ‏.‏\hadithno{5435}\hadithtrans{Narrated Anas:I was a young boy when I once was walking with Allah's Messenger (ﷺ) . Allah's Messenger (ﷺ) entered the house of his slave tailor and the latter brought a dish filled with food covered with pieces of gourd. Allah's Apostle started picking and eating the gourd. When I saw that, I started collecting and placing the gourd before him. Then the slave returned to his work. Anas added: I have kept on loving gourd since I saw Allah's Messenger (ﷺ) doing what he was doing}}
\hadithdefcmd{bukhari}{5436}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، أَنَّ خَيَّاطًا، دَعَا النَّبِيَّ صلى الله عليه وسلم لِطَعَامٍ صَنَعَهُ، فَذَهَبْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَقَرَّبَ خُبْزَ شَعِيرٍ وَمَرَقًا فِيهِ دُبَّاءٌ وَقَدِيدٌ، فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَتَتَبَّعُ الدُّبَّاءَ مِنْ حَوَالَىِ الْقَصْعَةِ، فَلَمْ أَزَلْ أُحِبُّ الدُّبَّاءَ بَعْدَ يَوْمِئِذٍ‏.‏\hadithno{5436}\hadithtrans{Narrated Anas bin Malik:A tailor invited the Prophet (ﷺ) to a meal which he had prepared, and I went along with the Prophet (ﷺ) . The tailor presented barley bread and soup containing gourd and cured meat. I saw the Prophet (ﷺ) picking the pieces of gourd from around the dish, and since then I have kept on liking gourd}}
\hadithdefcmd{bukhari}{5437}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِمَرَقَةٍ فِيهَا دُبَّاءٌ وَقَدِيدٌ، فَرَأَيْتُهُ يَتَتَبَّعُ الدُّبَّاءَ يَأْكُلُهَا‏.‏\hadithno{5437}\hadithtrans{Narrated Anas:I saw the Prophet (ﷺ) being served with soup and containing gourd and cured meat, and I saw him picking and eating the pieces of gourd}}
\hadithdefcmd{bukhari}{5438}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا فَعَلَهُ إِلاَّ فِي عَامٍ جَاعَ النَّاسُ، أَرَادَ أَنْ يُطْعِمَ الْغَنِيُّ الْفَقِيرَ، وَإِنْ كُنَّا لَنَرْفَعُ الْكُرَاعَ بَعْدَ خَمْسَ عَشْرَةَ، وَمَا شَبِعَ آلُ مُحَمَّدٍ صلى الله عليه وسلم مَنْ خُبْزِ بُرٍّ مَأْدُومٍ ثَلاَثًا‏.‏\hadithno{5438}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) did not do that (i.e., forbade the storage of the meat of sacrifices for three days) except (he did so) so that the rich would feed the poor. But later we used to keep even trotters to cook, fifteen days later. The family of Muhammad did not eat wheat bread with meat or soup to their satisfaction for three successive days}}
\hadithdefcmd{bukhari}{5439}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ إِنَّ خَيَّاطًا دَعَا رَسُولَ اللَّهِ صلى الله عليه وسلم لِطَعَامٍ صَنَعَهُ ـ قَالَ أَنَسٌ ـ فَذَهَبْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى ذَلِكَ الطَّعَامِ، فَقَرَّبَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم خُبْزًا مِنْ شَعِيرٍ وَمَرَقًا فِيهِ دُبَّاءٌ وَقَدِيدٌ ـ قَالَ أَنَسٌ ـ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَتَبَّعُ الدُّبَّاءَ مِنْ حَوْلِ الصَّحْفَةِ، فَلَمْ أَزَلْ أُحِبُّ الدُّبَّاءَ مِنْ يَوْمِئِذٍ‏.‏ وَقَالَ ثُمَامَةُ عَنْ أَنَسٍ، فَجَعَلْتُ أَجْمَعُ الدُّبَّاءَ بَيْنَ يَدَيْهِ‏.‏\hadithno{5439}\hadithtrans{Narrated Anas bin Malik:A tailor invited Allah's Messenger (ﷺ) to a meal which he had prepared. I went with Allah's Messenger (ﷺ) to that meal, and the tailor served the Prophet (ﷺ) with barley bread and soup of gourd and cured meat. I saw Allah's Messenger (ﷺ) picking the pieces of gourd from around the dish, and since then I have kept on liking gourd}}
\hadithdefcmd{bukhari}{5440}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرِ بْنِ أَبِي طَالِبٍ ـ رضى الله عنهما ـ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَأْكُلُ الرُّطَبَ بِالْقِثَّاءِ‏.‏\hadithno{5440}\hadithtrans{Narrated `Abdullah bin Ja`far bin Abi Talib:I saw Allah's Messenger (ﷺ) eating fresh dates with snake cucumber}}
\hadithdefcmd{bukhari}{5441}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَبَّاسٍ الْجُرَيْرِيِّ، عَنْ أَبِي عُثْمَانَ، قَالَ تَضَيَّفْتُ أَبَا هُرَيْرَةَ سَبْعًا، فَكَانَ هُوَ وَامْرَأَتُهُ وَخَادِمُهُ يَعْتَقِبُونَ اللَّيْلَ أَثْلاَثًا، يُصَلِّي هَذَا، ثُمَّ يُوقِظُ هَذَا‏.‏ وَسَمِعْتُهُ يَقُولُ قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنِ أَصْحَابِهِ تَمْرًا، فَأَصَابَنِي سَبْعُ تَمَرَاتٍ إِحْدَاهُنَّ حَشَفَةٌ‏.‏\hadithno{5441}\hadithtrans{Narrated Abu `Uthman:I was a guest of Abu Huraira for seven days. Abu Huraira, his wife and his slave used to get up and remain awake for one-third of the night by turns. Each would offer the night prayer and then awaken the other. I heard Abu Huraira saying, "Allah's Messenger (ﷺ) distributed dates among his companions and my share was seven dates, one of which was a Hashafa (a date which dried on the tree before it was fully ripe)}}
\hadithdefcmd{bukhari}{5441p2}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، عَنْ عَاصِمٍ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَسَمَ النَّبِيُّ صلى الله عليه وسلم بَيْنَنَا تَمْرًا فَأَصَابَنِي مِنْهُ خَمْسٌ أَرْبَعُ تَمَرَاتٍ وَحَشَفَةٌ، ثُمَّ رَأَيْتُ الْحَشَفَةَ هِيَ أَشَدُّهُنَّ لِضِرْسِي‏.‏\hadithno{5441.2}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) distributed dates among us, and my share was five dates, four of which were good, and one was a ,Hashafa, and I found the Hashafa the hardest for my teeth}}
\hadithdefcmd{bukhari}{5442}{وَقَالَ مُحَمَّدُ بْنُ يُوسُفَ عَنْ سُفْيَانَ، عَنْ مَنْصُورِ ابْنِ صَفِيَّةَ، حَدَّثَتْنِي أُمِّي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ شَبِعْنَا مِنَ الأَسْوَدَيْنِ التَّمْرِ وَالْمَاءِ‏.‏\hadithno{5442}\hadithtrans{Aishah (ra) said, "When Allah's Messenger (ﷺ) died, we had been satisfied by the two black things, i.e., dates and water}}
\hadithdefcmd{bukhari}{5443}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي رَبِيعَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، رضى الله عنهما قَالَ كَانَ بِالْمَدِينَةِ يَهُودِيٌّ وَكَانَ يُسْلِفُنِي فِي تَمْرِي إِلَى الْجِدَادِ، وَكَانَتْ لِجَابِرٍ الأَرْضُ الَّتِي بِطَرِيقِ رُومَةَ فَجَلَسَتْ، فَخَلاَ عَامًا فَجَاءَنِي الْيَهُودِيُّ عِنْدَ الْجَدَادِ، وَلَمْ أَجُدَّ مِنْهَا شَيْئًا، فَجَعَلْتُ أَسْتَنْظِرُهُ إِلَى قَابِلٍ فَيَأْبَى، فَأُخْبِرَ بِذَلِكَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ لأَصْحَابِهِ ‏"‏ امْشُوا نَسْتَنْظِرْ لِجَابِرٍ مِنَ الْيَهُودِيِّ ‏"‏‏.‏ فَجَاءُونِي فِي نَخْلِي فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يُكَلِّمُ الْيَهُودِيَّ فَيَقُولُ أَبَا الْقَاسِمِ لاَ أُنْظِرُهُ‏.‏ فَلَمَّا رَأَى النَّبِيُّ صلى الله عليه وسلم قَامَ فَطَافَ فِي النَّخْلِ، ثُمَّ جَاءَهُ فَكَلَّمَهُ فَأَبَى فَقُمْتُ فَجِئْتُ بِقَلِيلِ رُطَبٍ فَوَضَعْتُهُ بَيْنَ يَدَىِ النَّبِيِّ صلى الله عليه وسلم فَأَكَلَ ثُمَّ قَالَ ‏"‏ أَيْنَ عَرِيشُكَ يَا جَابِرُ ‏"‏‏.‏ فَأَخْبَرْتُهُ فَقَالَ ‏"‏ افْرُشْ لِي فِيهِ ‏"‏‏.‏ فَفَرَشْتُهُ فَدَخَلَ فَرَقَدَ، ثُمَّ اسْتَيْقَظَ فَجِئْتُهُ بِقَبْضَةٍ أُخْرَى فَأَكَلَ مِنْهَا، ثُمَّ قَامَ فَكَلَّمَ الْيَهُودِيَّ فَأَبَى عَلَيْهِ فَقَامَ فِي الرِّطَابِ فِي النَّخْلِ الثَّانِيَةَ ثُمَّ قَالَ ‏"‏ يَا جَابِرُ جُدَّ وَاقْضِ ‏"‏‏.‏ فَوَقَفَ فِي الْجَدَادِ فَجَدَدْتُ مِنْهَا مَا قَضَيْتُهُ وَفَضَلَ مِنْهُ فَخَرَجْتُ حَتَّى جِئْتُ النَّبِيَّ صلى الله عليه وسلم فَبَشَّرْتُهُ فَقَالَ ‏"‏ أَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏‏.‏ عُرُوشٌ وَعَرِيشٌ بِنَاءٌ وَقَالَ ابْنُ عَبَّاسٍ مَعْرُوشَاتٍ مَا يُعَرَّشُ مِنْ الْكُرُومِ وَغَيْرِ ذَلِكَ يُقَالُ عُرُوشُهَا أَبْنِيَتُهَا\hadithno{5443}\hadithtrans{Narrated Jabir bin `Abdullah:There was a Jew in Medina who used to lend me money up to the season of plucking dates. (Jabir had a piece of land which was on the way to Ruma). That year the land was not promising, so the payment of the debt was delayed one year. The Jew came to me at the time of plucking, but gathered nothing from my land. I asked him to give me one year respite, but he refused. This news reached the Prophet (ﷺ) whereupon he said to his companions, "Let us go and ask the Jew for respite for Jabir." All of them came to me in my garden, and the Prophet (ﷺ) started speaking to the Jew, but he Jew said, "O Abu Qasim! I will not grant him respite." When the Prophet (ﷺ) saw the Jew's attitude, he stood up and walked all around the garden and came again and talked to the Jew, but the Jew refused his request. I got up and brought some ripe fresh dates and put it in front of the Prophet. He ate and then said to me, "Where is your hut, O Jabir?" I informed him, and he said, "Spread out a bed for me in it." I spread out a bed, and he entered and slept. When he woke up, I brought some dates to him again and he ate of it and then got up and talked to the Jew again, but the Jew again refused his request. Then the Prophet (ﷺ) got up for the second time amidst the palm trees loaded with fresh dates, and said, "O Jabir! Pluck dates to repay your debt." The Jew remained with me while I was plucking the dates, till I paid him all his right, yet there remained extra quantity of dates. So I went out and proceeded till I reached the Prophet and informed him of the good news, whereupon he said, "I testify that I am Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{5444}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي مُجَاهِدٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ بَيْنَا نَحْنُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم جُلُوسٌ إِذْ أُتِيَ بِجُمَّارِ نَخْلَةٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ مِنَ الشَّجَرِ لَمَا بَرَكَتُهُ كَبَرَكَةِ الْمُسْلِمِ ‏"‏‏.‏ فَظَنَنْتُ أَنَّهُ يَعْنِي النَّخْلَةَ، فَأَرَدْتُ أَنْ أَقُولَ هِيَ النَّخْلَةُ يَا رَسُولَ اللَّهِ‏.‏ ثُمَّ الْتَفَتُّ فَإِذَا أَنَا عَاشِرُ عَشَرَةٍ أَنَا أَحْدَثُهُمْ فَسَكَتُّ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هِيَ النَّخْلَةُ ‏"‏‏.‏\hadithno{5444}\hadithtrans{Narrated `Abdullah bin `Umar:While we were sitting with the Prophet, fresh dates were brought to him. The Prophet (ﷺ) said, "There is a tree among the trees which is as blessed as a Muslim" I thought that it was the date palm tree and intended to say, "It is the date-palm tree, O Allah's Messenger (ﷺ)!" but I looked behind to see that I was the tenth and youngest of ten men present there, so I kept quiet' Then the Prophet (ﷺ) said, "It is the datepalm tree}}
\hadithdefcmd{bukhari}{5445}{حَدَّثَنَا جُمْعَةُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَرْوَانُ، أَخْبَرَنَا هَاشِمُ بْنُ هَاشِمٍ، أَخْبَرَنَا عَامِرُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَصَبَّحَ كُلَّ يَوْمٍ سَبْعَ تَمَرَاتٍ عَجْوَةً لَمْ يَضُرُّهُ فِي ذَلِكَ الْيَوْمِ سُمٌّ وَلاَ سِحْرٌ ‏"‏‏.‏\hadithno{5445}\hadithtrans{Narrated Sa`d:Allah's Messenger (ﷺ) said, "He who eats seven 'Ajwa dates every morning, will not be affected by poison or magic on the day he eats them}}
\hadithdefcmd{bukhari}{5446}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا جَبَلَةُ بْنُ سُحَيْمٍ، قَالَ أَصَابَنَا عَامُ سَنَةٍ مَعَ ابْنِ الزُّبَيْرِ فَرَزَقَنَا تَمْرًا، فَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَمُرُّ بِنَا وَنَحْنُ نَأْكُلُ وَيَقُولُ لاَ تُقَارِنُوا فَإِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْقِرَانِ‏.‏ ثُمَّ يَقُولُ إِلاَّ أَنْ يَسْتَأْذِنَ الرَّجُلُ أَخَاهُ‏.‏ قَالَ شُعْبَةُ الإِذْنُ مِنْ قَوْلِ ابْنِ عُمَرَ‏.‏\hadithno{5446}\hadithtrans{Narrated Jabala bin Suhaim.:At the time of Ibn Az-Zubair, we were struck with famine, and he provided us with dates for our food. `Abdullah bin `Umar used to pass by us while we were eating, and say, "Do not eat two dates together at a time, for the Prophet (ﷺ) forbade the taking of two dates together at a time (in a gathering)." Ibn `Umar used to add, "Unless one takes the permission of one's companions}}
\hadithdefcmd{bukhari}{5447}{حَدَّثَنِي إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ جَعْفَرٍ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَأْكُلُ الرُّطَبَ بِالْقِثَّاءِ‏.‏\hadithno{5447}\hadithtrans{Narrated `Abdullah bin Ja`far:I saw the Prophet (ﷺ) eating fresh dates with snake cucumbers}}
\hadithdefcmd{bukhari}{5448}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ طَلْحَةَ، عَنْ زُبَيْدٍ، عَنْ مُجَاهِدٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏مِنَ الشَّجَرِ شَجَرَةٌ تَكُونُ مِثْلَ الْمُسْلِمِ، وَهْىَ النَّخْلَةُ ‏"‏‏.‏\hadithno{5448}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "There is a tree among the trees which is similar to a Muslim (in goodness), and that is the date palm tree}}
\hadithdefcmd{bukhari}{5449}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ ـ رضى الله عنهما ـ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْكُلُ الرُّطَبَ بِالْقِثَّاءِ‏.‏\hadithno{5449}\hadithtrans{Narrated `Abdullah bin Ja`far:I saw Allah's Messenger (ﷺ) eating fresh dates with snake cucumbers}}
\hadithdefcmd{bukhari}{5450}{حَدَّثَنَا الصَّلْتُ بْنُ مُحَمَّدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنِ الْجَعْدِ أَبِي عُثْمَانَ، عَنْ أَنَسٍ،‏.‏ وَعَنْ هِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ،‏.‏ وَعَنْ سِنَانٍ أَبِي رَبِيعَةَ، عَنْ أَنَسٍ، أَنَّ أُمَّ سُلَيْمٍ، أُمَّهُ عَمَدَتْ إِلَى مُدٍّ مِنْ شَعِيرٍ، جَشَّتْهُ وَجَعَلَتْ مِنْهُ خَطِيفَةً، وَعَصَرَتْ عُكَّةً عِنْدَهَا، ثُمَّ بَعَثَتْنِي إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَتَيْتُهُ وَهْوَ فِي أَصْحَابِهِ فَدَعَوْتُهُ قَالَ ‏"‏ وَمَنْ مَعِي ‏"‏‏.‏ فَجِئْتُ فَقُلْتُ إِنَّهُ يَقُولُ، وَمَنْ مَعِي، فَخَرَجَ إِلَيْهِ أَبُو طَلْحَةَ قَالَ يَا رَسُولَ اللَّهِ إِنَّمَا هُوَ شَىْءٌ صَنَعَتْهُ أُمُّ سُلَيْمٍ، فَدَخَلَ فَجِيءَ بِهِ وَقَالَ ‏"‏ أَدْخِلْ عَلَىَّ عَشَرَةً ‏"‏‏.‏ فَدَخَلُوا فَأَكَلُوا حَتَّى شَبِعُوا، ثُمَّ قَالَ ‏"‏ أَدْخِلْ عَلَىَّ عَشَرَةً ‏"‏‏.‏ فَدَخَلُوا فَأَكَلُوا حَتَّى شَبِعُوا، ثُمَّ قَالَ ‏"‏ أَدْخِلْ عَلَىَّ عَشَرَةً ‏"‏‏.‏ حَتَّى عَدَّ أَرْبَعِينَ، ثُمَّ أَكَلَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَامَ، فَجَعَلْتُ أَنْظُرُ هَلْ نَقَصَ مِنْهَا شَىْءٌ‏.‏\hadithno{5450}\hadithtrans{Narrated Anas:My mother, Um Sulaim, took a Mudd of barley grain, ground it and made porridge from it, and pressed (over it), a butter skin she had with her. Then she sent me to the Prophet, and I reached him while he was sitting with his companions. I invited him, whereupon he said, "And those who are with me?' I returned and said, "He says, 'And those who are with me?" Abu Talha went out to him and said, "O Allah's Messenger (ﷺ)! It is just a meal prepared by Um Sulaim." The Prophet (ﷺ) entered and the food was brought to him. He said, "Let ten persons enter upon me." Those ten entered and ate their fill. Again he said, 'Let ten (more) enter upon me." Those ten entered and ate their fill. Then he said, "Let ten (more) enter upon me." He called forty persons in all Then Allah's Messenger (ﷺ) ate and got up. I started looking (at the food) to see if it decreased or not}}
\hadithdefcmd{bukhari}{5451}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، قَالَ قِيلَ لأَنَسٍ مَا سَمِعْتَ النَّبِيَّ صلى الله عليه وسلم فِي الثُّومِ فَقَالَ ‏ "‏ مَنْ أَكَلَ فَلاَ يَقْرَبَنَّ مَسْجِدَنَا ‏"‏‏.‏\hadithno{5451}\hadithtrans{Narrated `Abdul `Aziz:It was said to Anas "What did you hear the Prophet (ﷺ) saying about garlic?" Anas replied, "Whoever has eaten (garlic) should not approach our mosque}}
\hadithdefcmd{bukhari}{5452}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو صَفْوَانَ عَبْدُ اللَّهِ بْنُ سَعِيدٍ، أَخْبَرَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عَطَاءٌ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ زَعَمَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَكَلَ ثُومًا أَوْ بَصَلاً فَلْيَعْتَزِلْنَا، أَوْ لِيَعْتَزِلْ مَسْجِدَنَا ‏"‏‏.‏\hadithno{5452}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "Whoever has eaten garlic or onion should keep away from us (or should keep away from our mosque)}}
\hadithdefcmd{bukhari}{5453}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، قَالَ أَخْبَرَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمَرِّ الظَّهْرَانِ نَجْنِي الْكَبَاثَ فَقَالَ ‏"‏ عَلَيْكُمْ بِالأَسْوَدِ مِنْهُ، فَإِنَّهُ أَيْطَبُ ‏"‏‏.‏ فَقَالَ أَكُنْتَ تَرْعَى الْغَنَمَ قَالَ ‏"‏ نَعَمْ، وَهَلْ مِنْ نَبِيٍّ إِلاَّ رَعَاهَا ‏"‏‏.‏\hadithno{5453}\hadithtrans{Narrated Jabir bin `Abdullah:We were with Allah's Messenger (ﷺ) collecting Al-Kabath at Mar-Az-Zahran. The Prophet (ﷺ) said, "Collect the black ones, for they are better." Somebody said, (O Allah's Messenger (ﷺ)!) Have you ever shepherded sheep?" He said, "There has been no prophet but has shepherded them}}
\hadithdefcmd{bukhari}{5454}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ سُوَيْدِ بْنِ النُّعْمَانِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى خَيْبَرَ، فَلَمَّا كُنَّا بِالصَّهْبَاءِ دَعَا بِطَعَامٍ فَمَا أُتِيَ إِلاَّ بِسَوِيقٍ، فَأَكَلْنَا فَقَامَ إِلَى الصَّلاَةِ، فَتَمَضْمَضَ وَمَضْمَضْنَا‏.‏\hadithno{5454}\hadithtrans{Narrated Suwaid bin An Nu`man:We went out with Allah's Messenger (ﷺ) to Khaibar, and when we reached As-Sahba', the Prophet (ﷺ) asked for food, and he was offered nothing but Sawiq. We ate, and then Allah's Messenger (ﷺ) stood up for the prayer. He rinsed his mouth with water, and we too, rinsed our mouths}}
\hadithdefcmd{bukhari}{5455}{قَالَ يَحْيَى سَمِعْتُ بُشَيْرًا، يَقُولُ حَدَّثَنَا سُوَيْدٌ، خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى خَيْبَرَ، فَلَمَّا كُنَّا بِالصَّهْبَاءِ ـ قَالَ يَحْيَى وَهْىَ مِنْ خَيْبَرَ عَلَى رَوْحَةٍ ـ دَعَا بِطَعَامٍ فَمَا أُتِيَ إِلاَّ بِسَوِيقٍ، فَلُكْنَاهُ فَأَكَلْنَا مَعَهُ، ثُمَّ دَعَا بِمَاءٍ فَمَضْمَضَ وَمَضْمَضْنَا مَعَهُ، ثُمَّ صَلَّى بِنَا الْمَغْرِبَ وَلَمْ يَتَوَضَّأْ‏.‏ وَقَالَ سُفْيَانُ كَأَنَّكَ تَسْمَعُهُ مِنْ يَحْيَى‏.‏\hadithno{5455}\hadithtrans{Narrated Suwaid:We went out with Allah's Messenger (ﷺ) to Khaibar. and when we reached As-Sahba', which (Yahya says) is one day' journey from Khaibar, the Prophet (ﷺ) asked for food, and he was offered nothing but Sawiq which we chewed and ate. Then the Prophet (ﷺ) asked for water and rinsed his mouth, and we too, rinsed our mouths along with him. He then led us in the Maghrib prayer without performing ablution again}}
\hadithdefcmd{bukhari}{5456}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَكَلَ أَحَدُكُمْ فَلاَ يَمْسَحْ يَدَهُ حَتَّى يَلْعَقَهَا أَوْ يُلْعِقَهَا ‏"‏‏.‏\hadithno{5456}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, 'When you eat, do not wipe your hands till you have licked it, or had it licked by somebody else}}
\hadithdefcmd{bukhari}{5457}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ فُلَيْحٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ سَعِيدِ بْنِ الْحَارِثِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّهُ سَأَلَهُ عَنِ الْوُضُوءِ مِمَّا مَسَّتِ النَّارُ، فَقَالَ لاَ قَدْ كُنَّا زَمَانَ النَّبِيِّ صلى الله عليه وسلم لاَ نَجِدُ مِثْلَ ذَلِكَ مِنَ الطَّعَامِ إِلاَّ قَلِيلاً، فَإِذَا نَحْنُ وَجَدْنَاهُ لَمْ يَكُنْ لَنَا مَنَادِيلُ، إِلاَّ أَكُفَّنَا وَسَوَاعِدَنَا وَأَقْدَامَنَا، ثُمَّ نُصَلِّي وَلاَ نَتَوَضَّأُ‏.‏\hadithno{5457}\hadithtrans{Narrated Sa`id bin Al-Harith:that he asked Jabir bin `Abdullah about performing ablution after taking a cooked meal. He replied, "It is not essential," and added, "We never used to get such kind of food during the lifetime of the Prophet except rarely; and if at all we got such a dish, we did not have any handkerchiefs to wipe our hands with except the palms of our hands, our forearms and our feet. We would perform the prayer thereafter with-out performing new ablution}}
\hadithdefcmd{bukhari}{5458}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ ثَوْرٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ أَبِي أُمَامَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا رَفَعَ مَائِدَتَهُ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ، غَيْرَ مَكْفِيٍّ، وَلاَ مُوَدَّعٍ وَلاَ مُسْتَغْنًى عَنْهُ، رَبَّنَا ‏"‏‏.‏\hadithno{5458}\hadithtrans{Narrated Abu Umama:Whenever the dining sheet of the Prophet (ﷺ) was taken away (i.e., whenever he finished his meal), he used to say: "Al-hamdu li l-lah kathiran taiyiban mubarakan fihi ghaira makfiy wala muWada` wala mustaghna'anhu Rabbuna}}
\hadithdefcmd{bukhari}{5459}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ أَبِي أُمَامَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا فَرَغَ مِنْ طَعَامِهِ ـ وَقَالَ مَرَّةً إِذَا رَفَعَ مَائِدَتَهُ ـ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي كَفَانَا وَأَرْوَانَا، غَيْرَ مَكْفِيٍّ، وَلاَ مَكْفُورٍ ـ وَقَالَ مَرَّةً الْحَمْدُ لِلَّهِ رَبِّنَا، غَيْرَ مَكْفِيٍّ، وَلاَ مُوَدَّعٍ ـ وَلاَ مُسْتَغْنًى، رَبَّنَا ‏"‏‏.‏\hadithno{5459}\hadithtrans{Narrated Abu Umama:Whenever the Prophet (ﷺ) finished his meals (or when his dining sheet was taken away), he used to say. "Praise be to Allah Who has satisfied our needs and quenched our thirst. Your favor cannot by compensated or denied." Once he said, upraise be to You, O our Lord! Your favor cannot be compensated, nor can be left, nor can be dispensed with, O our Lord}}
\hadithdefcmd{bukhari}{5460}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدٍ ـ هُوَ ابْنُ زِيَادٍ ـ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَتَى أَحَدَكُمْ خَادِمُهُ بِطَعَامِهِ، فَإِنْ لَمْ يُجْلِسْهُ مَعَهُ فَلْيُنَاوِلْهُ أُكْلَةً أَوْ أُكْلَتَيْنِ، أَوْ لُقْمَةً أَوْ لُقْمَتَيْنِ، فَإِنَّهُ وَلِيَ حَرَّهُ وَعِلاَجَهُ ‏"‏‏.‏\hadithno{5460}\hadithtrans{Narrated .Abu Huraira:The Prophet (ﷺ) said, "When your servant brings your food to you, if you do not ask him to join you, then at least ask him to take one or two handfuls, for he has suffered from its heat (while cooking it) and has taken pains to cook it nicely}}
\hadithdefcmd{bukhari}{5461}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا شَقِيقٌ، حَدَّثَنَا أَبُو مَسْعُودٍ الأَنْصَارِيُّ، قَالَ كَانَ رَجُلٌ مِنَ الأَنْصَارِ يُكْنَى أَبَا شُعَيْبٍ، وَكَانَ لَهُ غُلاَمٌ لَحَّامٌ، فَأَتَى النَّبِيَّ صلى الله عليه وسلم وَهْوَ فِي أَصْحَابِهِ، فَعَرَفَ الْجُوعَ فِي وَجْهِ النَّبِيِّ صلى الله عليه وسلم فَذَهَبَ إِلَى غُلاَمِهِ اللَّحَّامِ فَقَالَ اصْنَعْ لِي طَعَامًا يَكْفِي خَمْسَةً، لَعَلِّي أَدْعُو النَّبِيَّ صلى الله عليه وسلم خَامِسَ خَمْسَةٍ‏.‏ فَصَنَعَ لَهُ طُعَيِّمًا، ثُمَّ أَتَاهُ فَدَعَاهُ، فَتَبِعَهُمْ رَجُلٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أَبَا شُعَيْبٍ إِنَّ رَجُلاً تَبِعَنَا فَإِنْ شِئْتَ أَذِنْتَ لَهُ، وَإِنْ شِئْتَ تَرَكْتَهُ ‏"‏‏.‏ قَالَ لاَ بَلْ أَذِنْتُ لَهُ‏.‏\hadithno{5461}\hadithtrans{Narrated Abu Mas`ud Al-Ansari:There was an Ansari man nicknamed, Abu Shu'aib, who had a slave who was a butcher. He came to the Prophet (ﷺ) while he was sitting with his companions and noticed the signs of hunger on the face of the Prophet (ﷺ) . So he went to his butcher slave and said, "Prepare for me a meal sufficient for five persons so that I may invite the Prophet (ﷺ) along with four other men." He had the meal prepared for him and invited him. A (sixth) man followed them. The Prophet (ﷺ) said, "O Abu Shu'aib! Another man has followed us. If you wish, you may invite him; and if you wish, you may refuse him." Abu Shu'aib said, "No, I will admit him}}
\hadithdefcmd{bukhari}{5462}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ،‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي جَعْفَرُ بْنُ عَمْرِو بْنِ أُمَيَّةَ، أَنَّ أَبَاهُ، عَمْرَو بْنَ أُمَيَّةَ أَخْبَرَهُ أَنَّهُ، رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يَحْتَزُّ مِنْ كَتِفِ شَاةٍ فِي يَدِهِ، فَدُعِيَ إِلَى الصَّلاَةِ فَأَلْقَاهَا وَالسِّكِّينَ الَّتِي كَانَ يَحْتَزُّ بِهَا، ثُمَّ قَامَ فَصَلَّى، وَلَمْ يَتَوَضَّأْ‏.‏\hadithno{5462}\hadithtrans{Narrated `Amr bin Umaiyya:That he saw Allah's Messenger (ﷺ) cutting a piece of mutton from its shoulder part he was carrying in his hand. When he was called for prayer, he put it down and the knife with which he was cutting it. Then he stood up and offered the prayer without performing new ablution}}
\hadithdefcmd{bukhari}{5463}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وُضِعَ الْعَشَاءُ وَأُقِيمَتِ الصَّلاَةُ فَابْدَءُوا بِالْعَشَاءِ ‏"‏‏.‏\hadithno{5463}\hadithtrans{Narrated Anas bin Malik: The Prophet (ﷺ) said, If supper is served and the Iqama for (Isha) prayer is proclaimed, start with you supper first}}
\hadithdefcmd{bukhari}{5464}{وَعَنْ أَيُّوبَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ‏.‏ وَعَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ تَعَشَّى مَرَّةً وَهْوَ يَسْمَعُ قِرَاءَةَ الإِمَامِ‏.‏\hadithno{5464}\hadithtrans{Narrated Nafi: Once Ibn Umar was taking his supper while he was listening to the recitation of (Quran by) the Imam (in the Isha prayer)}}
\hadithdefcmd{bukhari}{5465}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أُقِيمَتِ الصَّلاَةُ وَحَضَرَ الْعَشَاءُ فَابْدَءُوا بِالْعَشَاءِ ‏"‏‏.‏ قَالَ وُهَيْبٌ وَيَحْيَى بْنُ سَعِيدٍ عَنْ هِشَامٍ ‏"‏ إِذَا وُضِعَ الْعَشَاءُ ‏"‏‏.‏\hadithno{5465}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) said, "If the Iqama for (`Isha') prayer is proclaimed and supper is served, take your supper first}}
\hadithdefcmd{bukhari}{5466}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَنَسًا، قَالَ أَنَا أَعْلَمُ النَّاسِ، بِالْحِجَابِ كَانَ أُبَىُّ بْنُ كَعْبٍ يَسْأَلُنِي عَنْهُ، أَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَرُوسًا بِزَيْنَبَ ابْنَةِ جَحْشٍ وَكَانَ تَزَوَّجَهَا بِالْمَدِينَةِ، فَدَعَا النَّاسَ لِلطَّعَامِ بَعْدَ ارْتِفَاعِ النَّهَارِ، فَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَجَلَسَ مَعَهُ رِجَالٌ بَعْدَ مَا قَامَ الْقَوْمُ، حَتَّى قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَمَشَى وَمَشَيْتُ مَعَهُ، حَتَّى بَلَغَ باب حُجْرَةِ عَائِشَةَ، ثُمَّ ظَنَّ أَنَّهُمْ خَرَجُوا فَرَجَعْتُ مَعَهُ، فَإِذَا هُمْ جُلُوسٌ مَكَانَهُمْ، فَرَجَعَ وَرَجَعْتُ مَعَهُ الثَّانِيَةَ، حَتَّى بَلَغَ باب حُجْرَةِ عَائِشَةَ فَرَجَعَ وَرَجَعْتُ مَعَهُ، فَإِذَا هُمْ قَامُوا، فَضَرَبَ بَيْنِي وَبَيْنَهُ سِتْرًا، وَأُنْزِلَ الْحِجَابُ‏.‏\hadithno{5466}\hadithtrans{Narrated Anas:I know (about) the Hijab (the order of veiling of women) more than anybody else. Ubai bin Ka`b used to ask me about it. Allah's Messenger (ﷺ) became the bridegroom of Zainab bint Jahsh whom he married at Medina. After the sun had risen high in the sky, the Prophet (ﷺ) invited the people to a meal. Allah's Apostle remained sitting and some people remained sitting with him after the other guests had left. Then Allah's Messenger (ﷺ) got up and went away, and I too, followed him till he reached the door of `Aisha's room. Then he thought that the people must have left the place by then, so he returned and I also returned with him. Behold, the people were still sitting at their places. So he went back again for the second time, and I went along with him too. When we reached the door of `Aisha's room, he returned and I also returned with him to see that the people had left. Thereupon the Prophet (ﷺ) hung a curtain between me and him and the Verse regarding the order for (veiling of women) Hijab was revealed}}
